#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Date    : 2021-09-06 15:52:46
# @Author  : wangmian05
# @Link    : wangmian05@countrygraden.com.cn
# @Version : $Id$
import json
import time

from aisrfwk.redis.redis_core import re_pool, setHash, lPush
from aisrfwk.util.config import config
from aisrfwk.util import log as log
from aisrfwk.util.mail_util import sendMail

global_key = config.get("redis.global_key", "aisr-fwk")
aisr_queue_key = global_key + ":" + config.get("redis.park_task_queue", "task_queue")
aisr_task_status_key = global_key + ":" + config.get("redis.park_task_status", "task_status")
aisr_task_data_key = global_key + ":" + config.get("redis.park_task_data", "task_data")
aisr_send_mail_key = global_key + ":" + config.get("redis.send_mail", "send_mail")

task_status = {"todo": 1, "running": 2, "success": "3", "error": "4"}


def putTask(_task_id, content):
    data = {"status": task_status.get("todo"), "putTime": int(round(time.time() * 1000))}
    setHash(aisr_task_status_key, _task_id, json.dumps(data))
    setHash(aisr_task_data_key, _task_id, content)
    lPush(aisr_queue_key, content)


def startTask(_task_id):
    data = getTaskStatus(_task_id)
    if data is None:
        log.warning("[startTask]当前缓存中不存在此任务:{},放弃处理错误", data)
        return
    data["startTime"] = int(round(time.time() * 1000))
    data["startDate"] = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(time.time()))
    re_pool.hset(aisr_task_status_key, _task_id, json.dumps(data))


def runningTask(_task_id):
    data = getTaskStatus(_task_id)
    if data is None:
        log.warning("[runningTask]当前缓存中不存在此任务:{},放弃处理错误", data)
        return
    data["status"] = task_status.get("running")
    data["runningTime"] = time.time()
    data["runningDate"] = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(time.time()))
    re_pool.hset(aisr_task_status_key, _task_id, json.dumps(data))


def updateTaskStatus(_task_id, status):
    data = getTaskStatus(_task_id)
    if data is None:
        log.warning("[updateTaskStatus]当前缓存中不存在此任务:{},放弃处理错误", data)
        return
    data["status"] = status
    re_pool.hset(aisr_task_status_key, _task_id, json.dumps(data))


def getTaskStatus(_task_id):
    data = re_pool.hget(aisr_task_status_key, _task_id)
    if data is not None:
        return json.loads(data)
    else:
        return data


def restartTodoRunTask(_task_id=None):
    task_list_data = re_pool.hgetall(aisr_task_status_key)
    for tkd in task_list_data:
        key = bytes.decode(tkd)
        tk_val = json.loads(task_list_data[tkd])
        # log.info("当前key:{}结果:{}", key, tk_val)
        if _task_id is not None:
            if key == _task_id:
                h_data = re_pool.hget(aisr_task_data_key, _task_id)
                if h_data is not None and tk_val["status"] == task_status.get("todo"):
                    task_data_str = bytes.decode(h_data, "utf-8")
                    log.info("当前需要把任务:{}重新装回队列...", key)
                    lPush(aisr_queue_key, task_data_str)
        else:
            h_data = re_pool.hget(aisr_task_data_key, key)
            if h_data is not None and tk_val["status"] == task_status.get("todo"):
                task_data_str = bytes.decode(h_data, "utf-8")
                log.info("当前需要把任务:{}重新装回队列...", key)
                lPush(aisr_queue_key, task_data_str)

    return None


def overTaskStatus(_task_id):
    data = getTaskStatus(_task_id)
    if data is None:
        log.warning("[errorTaskStatus]当前缓存中不存在此任务:{},放弃处理错误", data)
        return
    # if data["status"] == task_status.get("error"):
    #     log.warning("[errorTaskStatus]任务执行过程中出现异常:{},暂时无需删除错误信息", data)
    #     return
    re_pool.hdel(aisr_task_status_key, _task_id)
    re_pool.hdel(aisr_task_data_key, _task_id)
    re_pool.delete(aisr_send_mail_key + _task_id)


def buildSendData(_task_id):
    _task_data = re_pool.hget(aisr_task_data_key, _task_id)
    _task_data_str = bytes.decode(_task_data, "utf-8")
    _pro_name = None
    _creator = None
    if _task_data is not None:
        json_data = json.loads(_task_data)
        # 项目名称
        _pro_name = json_data.get("projectName") if json_data.get("projectName") else None
        # 创建人
        _creator = json_data.get("creator") if json_data.get("creator") else None
    return _task_data_str, _pro_name, _creator


def errorTaskStatus(_task_id, _msg, send_mail=True):
    _status_data = getTaskStatus(_task_id)
    if _status_data is None:
        log.warning("[errorTaskStatus]当前缓存中不存在此任务:{},放弃处理错误", _status_data)
        return
    # 暂时打开所有错误都发送邮件功能
    # send_mail = _status_data["status"] == task_status.get("running")
    # 如果单个任务超过10个邮件就不再发了.发多了也没啥意义
    if incr(_task_id) > 10:
        send_mail = False
    _status_data["status"] = task_status.get("error")
    _status_data["errorTime"] = int(round(time.time() * 1000))
    _status_data["errorDate"] = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(time.time()))
    _status_data["errorMsg"] = _msg
    re_pool.hset(aisr_task_status_key, _task_id, json.dumps(_status_data))
    # 发送邮件通知
    if send_mail:
        try:
            log.info("开始发送错误邮件...")
            _task_data_str, _pro_name, _creator = buildSendData(_task_id)
            sendMail(_msg, _task_data_str, _project_name=_pro_name, _creator=_creator)
        except Exception as e:
            log.error("邮件发送错误:{}", str(e))


def incr(taskId):
    return re_pool.incr(aisr_send_mail_key + taskId)


if __name__ == "__main__":
    queue_key = "aisr:park_task_queue"
    value = "{\"building\": [[[92356, -81123], [92356, -88623], [91856, -88623], [91856, -89223], [88756, -89223], [88756, -90123], [82756, -90123], [82756, -88623], [81956, -88623], [81956, -89223], [76756, -89223], [76756, -88623], [75956, -88623], [75956, -90123], [69956, -90123], [69956, -89223], [66856, -89223], [66856, -88623], [66356, -88623], [66356, -81123], [72856, -81123], [72856, -80223], [77906, -80223], [77906, -76923], [77706, -76923], [77706, -76523], [81006, -76523], [81006, -76923], [80806, -76923], [80806, -80223], [85856, -80223], [85856, -81123]], [[40256, -81123], [40256, -88623], [40756, -88623], [40756, -89223], [43856, -89223], [43856, -90123], [49856, -90123], [49856, -88623], [50656, -88623], [50656, -89223], [55856, -89223], [55856, -88623], [56656, -88623], [56656, -90123], [62656, -90123], [62656, -89223], [65756, -89223], [65756, -88623], [66256, -88623], [66256, -81123], [59756, -81123], [59756, -80223], [54706, -80223], [54706, -76923], [54906, -76923], [54906, -76523], [51606, -76523], [51606, -76923], [51806, -76923], [51806, -80223], [46756, -80223], [46756, -81123]], [[-27950, -40235], [-28450, -40235], [-28450, -40834], [-31550, -40834], [-31550, -41734], [-39249, -41734], [-39249, -40234], [-40049, -40234], [-40049, -40834], [-44650, -40834], [-44650, -40234], [-45450, -40234], [-45450, -41734], [-53150, -41734], [-53150, -40834], [-56250, -40834], [-56250, -40234], [-56750, -40234], [-56750, -32333], [-46349, -32334], [-46349, -32034], [-45849, -32034], [-45849, -29734], [-45149, -29734], [-45149, -28484], [-40549, -28484], [-40549, -29334], [-38349, -29334], [-38349, -32334], [-27950, -32334]], [[-27349, 10021], [-26849, 10021], [-26849, 9422], [-23749, 9422], [-23749, 8523], [-16050, 8522], [-16050, 10023], [-15250, 10023], [-15250, 9423], [-10649, 9423], [-10649, 10023], [-9849, 10023], [-9849, 8523], [-2149, 8523], [-2149, 9423], [950, 9423], [950, 10023], [1450, 10023], [1450, 17923], [-8950, 17923], [-8950, 18223], [-9450, 18223], [-9450, 20523], [-10150, 20523], [-10150, 21773], [-14750, 21773], [-14750, 20923], [-16950, 20923], [-16950, 17923], [-27349, 17923]], [[30400, 10021], [29900, 10021], [29900, 9422], [26800, 9422], [26800, 8523], [19100, 8522], [19100, 10023], [18300, 10023], [18300, 9423], [13699, 9423], [13699, 10023], [12899, 10023], [12899, 8523], [5200, 8523], [5200, 9423], [2100, 9423], [2100, 10023], [1600, 10023], [1600, 17923], [12000, 17923], [12000, 18223], [12500, 18223], [12500, 20523], [13200, 20523], [13200, 21773], [17800, 21773], [17800, 20923], [20000, 20923], [20000, 17923], [30400, 17923]], [[56964, 71302], [56964, 63802], [56464, 63802], [56464, 63202], [53364, 63202], [53364, 62302], [47364, 62302], [47364, 63802], [46564, 63802], [46564, 63202], [41364, 63202], [41364, 63802], [40564, 63802], [40564, 62302], [34564, 62302], [34564, 63202], [31464, 63202], [31464, 63802], [30964, 63802], [30964, 71302], [37464, 71302], [37464, 72202], [40664, 72202], [40664, 76052], [45764, 76052], [45764, 73352], [45964, 73352], [45964, 71452], [47064, 71452], [47064, 72202], [50464, 72202], [50464, 71302]], [[56884, -15912], [56884, -23412], [56384, -23412], [56384, -24012], [53284, -24012], [53284, -24912], [47284, -24912], [47284, -23412], [46484, -23412], [46484, -24012], [41284, -24012], [41284, -23412], [40484, -23412], [40484, -24912], [34484, -24912], [34484, -24012], [31384, -24012], [31384, -23412], [30884, -23412], [30884, -15912], [37384, -15912], [37384, -15012], [40584, -15012], [40584, -11162], [45684, -11162], [45684, -13862], [45884, -13862], [45884, -15762], [46984, -15762], [46984, -15012], [50384, -15012], [50384, -15912]], [[-82857, 69270], [-82857, 61770], [-82357, 61770], [-82357, 61170], [-79257, 61170], [-79257, 60270], [-73257, 60270], [-73257, 61770], [-72457, 61770], [-72457, 61170], [-67257, 61170], [-67257, 61770], [-66457, 61770], [-66457, 60270], [-60457, 60270], [-60457, 61170], [-57357, 61170], [-57357, 61770], [-56857, 61770], [-56857, 69270], [-63357, 69270], [-63357, 70170], [-66557, 70170], [-66557, 74020], [-71657, 74020], [-71657, 71320], [-71857, 71320], [-71857, 69420], [-72957, 69420], [-72957, 70170], [-76357, 70170], [-76357, 69270]], [[57095, 71302], [57095, 63802], [57595, 63802], [57595, 63202], [60695, 63202], [60695, 62302], [66695, 62302], [66695, 63802], [67495, 63802], [67495, 63202], [72695, 63202], [72695, 63802], [73495, 63802], [73495, 62302], [79495, 62302], [79495, 63202], [82595, 63202], [82595, 63802], [83095, 63802], [83095, 71302], [76595, 71302], [76595, 72202], [73395, 72202], [73395, 76052], [68295, 76052], [68295, 73352], [68095, 73352], [68095, 71452], [66995, 71452], [66995, 72202], [63595, 72202], [63595, 71302]], [[57015, -15912], [57015, -23412], [57515, -23412], [57515, -24012], [60615, -24012], [60615, -24912], [66615, -24912], [66615, -23412], [67415, -23412], [67415, -24012], [72615, -24012], [72615, -23412], [73415, -23412], [73415, -24912], [79415, -24912], [79415, -24012], [82515, -24012], [82515, -23412], [83015, -23412], [83015, -15912], [76515, -15912], [76515, -15012], [73315, -15012], [73315, -11162], [68215, -11162], [68215, -13862], [68015, -13862], [68015, -15762], [66915, -15762], [66915, -15012], [63515, -15012], [63515, -15912]], [[-82900, -32734], [-82900, -40234], [-82400, -40234], [-82400, -40834], [-79300, -40834], [-79300, -41734], [-73300, -41734], [-73300, -40234], [-72500, -40234], [-72500, -40834], [-67300, -40834], [-67300, -40234], [-66500, -40234], [-66500, -41734], [-60500, -41734], [-60500, -40834], [-57400, -40834], [-57400, -40234], [-56900, -40234], [-56900, -32734], [-63400, -32734], [-63400, -31834], [-66600, -31834], [-66600, -27984], [-71700, -27984], [-71700, -30684], [-71900, -30684], [-71900, -32584], [-73000, -32584], [-73000, -31834], [-76400, -31834], [-76400, -32734]], [[96991, 39355], [96991, 31955], [97591, 31955], [97591, 31355], [100391, 31355], [100391, 30455], [106991, 30455], [106991, 30855], [108391, 30855], [108391, 30455], [114090, 30455], [114090, 31375], [116691, 31375], [116691, 31955], [117690, 31955], [117690, 31375], [120290, 31375], [120290, 30455], [125990, 30455], [125990, 30855], [127390, 30855], [127390, 30455], [133990, 30455], [133990, 31355], [136791, 31355], [136791, 31955], [137390, 31955], [137390, 39355], [130990, 39355], [130990, 46505], [131190, 46505], [131190, 46905], [125490, 46905], [125490, 45655], [123190, 45655], [123190, 41755], [121840, 41755], [121840, 40755], [122390, 40755], [122390, 38955], [111990, 38955], [111990, 40755], [112641, 40755], [112641, 41755], [111291, 41755], [111291, 45555], [108591, 45555], [108591, 46905], [103391, 46905], [103391, 39355]], [[-12056, 99735], [-12055, 92335], [-11456, 92335], [-11456, 91735], [-8656, 91735], [-8656, 90835], [-2056, 90835], [-2056, 91235], [-656, 91235], [-656, 90835], [5043, 90835], [5043, 91755], [7643, 91755], [7643, 92335], [8642, 92335], [8642, 91755], [11243, 91755], [11243, 90835], [16942, 90835], [16942, 91235], [18342, 91235], [18342, 90835], [24942, 90835], [24942, 91735], [27743, 91735], [27743, 92335], [28342, 92335], [28342, 99735], [21942, 99735], [21942, 106886], [22142, 106886], [22142, 107285], [16442, 107285], [16442, 106035], [14142, 106035], [14142, 102135], [12792, 102135], [12792, 101135], [13343, 101135], [13343, 99335], [2943, 99335], [2943, 101135], [3593, 101135], [3593, 102135], [2243, 102135], [2243, 105935], [-456, 105935], [-456, 107285], [-5656, 107285], [-5656, 99735]], [[-128394, 111246], [-128394, 103846], [-127794, 103846], [-127794, 103246], [-124994, 103246], [-124994, 102346], [-118394, 102346], [-118394, 102746], [-116994, 102746], [-116994, 102346], [-111295, 102346], [-111295, 103266], [-108694, 103266], [-108694, 103846], [-107695, 103846], [-107695, 103266], [-105095, 103266], [-105095, 102346], [-99395, 102346], [-99395, 102746], [-97995, 102746], [-97995, 102346], [-91395, 102346], [-91395, 103246], [-88594, 103246], [-88594, 103846], [-87995, 103846], [-87995, 111246], [-94395, 111246], [-94395, 118396], [-94195, 118396], [-94195, 118796], [-99895, 118796], [-99895, 117546], [-102195, 117546], [-102195, 113646], [-103545, 113646], [-103545, 112646], [-102995, 112646], [-102995, 110846], [-113395, 110846], [-113395, 112646], [-112744, 112646], [-112744, 113646], [-114094, 113646], [-114094, 117446], [-116794, 117446], [-116794, 118796], [-121994, 118796], [-121994, 111246]], [[-132675, 33460], [-132675, 26060], [-132075, 26060], [-132075, 25460], [-129275, 25460], [-129275, 24560], [-122675, 24560], [-122675, 24960], [-121275, 24960], [-121275, 24560], [-115576, 24560], [-115576, 25480], [-112975, 25480], [-112975, 26060], [-111976, 26060], [-111976, 25480], [-109376, 25480], [-109376, 24560], [-103676, 24560], [-103676, 24960], [-102276, 24960], [-102276, 24560], [-95676, 24560], [-95676, 25460], [-92875, 25460], [-92875, 26060], [-92276, 26060], [-92276, 33460], [-98676, 33460], [-98676, 40611], [-98476, 40611], [-98476, 41010], [-104176, 41010], [-104176, 39760], [-106476, 39760], [-106476, 35860], [-107826, 35860], [-107826, 34860], [-107276, 34860], [-107276, 33060], [-117676, 33060], [-117676, 34860], [-117025, 34860], [-117025, 35860], [-118375, 35860], [-118375, 39660], [-121075, 39660], [-121075, 41010], [-126275, 41010], [-126275, 33460]], [[-136258, -43198], [-136257, -50598], [-135658, -50598], [-135658, -51198], [-132857, -51198], [-132857, -52098], [-126258, -52098], [-126258, -51698], [-124858, -51698], [-124858, -52098], [-119158, -52098], [-119158, -51178], [-116558, -51178], [-116558, -50598], [-115558, -50598], [-115558, -51178], [-112958, -51178], [-112958, -52098], [-107258, -52098], [-107258, -51698], [-105858, -51698], [-105858, -52098], [-99259, -52098], [-99259, -51198], [-96458, -51198], [-96458, -50598], [-95858, -50598], [-95858, -43198], [-102258, -43198], [-102258, -36048], [-102058, -36048], [-102058, -35648], [-107758, -35648], [-107758, -36898], [-110058, -36898], [-110058, -40798], [-111408, -40798], [-111408, -41798], [-110858, -41798], [-110858, -43598], [-121258, -43598], [-121258, -41798], [-120608, -41798], [-120608, -40798], [-121958, -40798], [-121958, -36998], [-124658, -36998], [-124658, -35648], [-129858, -35648], [-129858, -43198]], [[-5102, -64971], [-5102, -72471], [-4602, -72471], [-4602, -73071], [-1502, -73071], [-1502, -73971], [4497, -73971], [4497, -72471], [5297, -72471], [5297, -73071], [10497, -73071], [10497, -72471], [11297, -72471], [11297, -73971], [17297, -73971], [17297, -73071], [20397, -73071], [20397, -72471], [20897, -72471], [20897, -64971], [14397, -64971], [14397, -64071], [11197, -64071], [11197, -60221], [6097, -60221], [6097, -62921], [5897, -62921], [5897, -64821], [4797, -64821], [4797, -64071], [1397, -64071], [1397, -64971]], [[-86991, -125934], [-86990, -133334], [-86391, -133334], [-86391, -133934], [-83591, -133934], [-83591, -134834], [-76991, -134834], [-76991, -134434], [-75591, -134434], [-75591, -134835], [-69891, -134835], [-69891, -133914], [-67291, -133914], [-67291, -133335], [-66292, -133335], [-66292, -133914], [-63691, -133914], [-63691, -134835], [-57992, -134835], [-57992, -134434], [-56592, -134434], [-56592, -134834], [-49992, -134834], [-49992, -133934], [-47191, -133934], [-47191, -133334], [-46592, -133334], [-46592, -125934], [-52992, -125934], [-52992, -118784], [-52792, -118784], [-52792, -118384], [-58492, -118384], [-58492, -119634], [-60792, -119634], [-60792, -123534], [-62142, -123535], [-62142, -124534], [-61591, -124534], [-61591, -126334], [-71991, -126334], [-71991, -124534], [-71341, -124534], [-71341, -123534], [-72691, -123534], [-72691, -119734], [-75391, -119734], [-75391, -118384], [-80591, -118384], [-80591, -125934]], [[96891, 111044], [96891, 103644], [97491, 103644], [97491, 103044], [100291, 103044], [100291, 102144], [106891, 102144], [106891, 102544], [108291, 102544], [108291, 102144], [113990, 102144], [113990, 103064], [116591, 103064], [116591, 103644], [117590, 103644], [117590, 103064], [120190, 103064], [120190, 102144], [125890, 102144], [125890, 102544], [127290, 102544], [127290, 102144], [133890, 102144], [133890, 103044], [136691, 103044], [136691, 103644], [137290, 103644], [137290, 111044], [130890, 111044], [130890, 118194], [131090, 118194], [131090, 118594], [125390, 118594], [125390, 117344], [123090, 117344], [123090, 113444], [121740, 113444], [121740, 112444], [122290, 112444], [122290, 110644], [111890, 110644], [111891, 112444], [112541, 112444], [112541, 113444], [111191, 113444], [111191, 117244], [108491, 117244], [108491, 118594], [103291, 118594], [103291, 111044]], [[14045, -125744], [14045, -133244], [14545, -133244], [14545, -133844], [17645, -133844], [17645, -134744], [23645, -134744], [23645, -133244], [24445, -133244], [24445, -133844], [29645, -133844], [29645, -133244], [30445, -133244], [30444, -134744], [36445, -134744], [36445, -133844], [39545, -133844], [39545, -133244], [40045, -133244], [40045, -125744], [33545, -125744], [33545, -124844], [28495, -124844], [28495, -121544], [28695, -121544], [28695, -121144], [25394, -121144], [25394, -121544], [25595, -121544], [25595, -124844], [20545, -124844], [20545, -125744]], [[-33392, -125994], [-33392, -133494], [-32892, -133494], [-32892, -134094], [-29792, -134094], [-29792, -134994], [-23792, -134994], [-23792, -133494], [-22992, -133494], [-22992, -134094], [-17792, -134094], [-17792, -133494], [-16992, -133494], [-16992, -134994], [-10992, -134994], [-10992, -134094], [-7892, -134094], [-7892, -133494], [-7392, -133494], [-7392, -125994], [-13892, -125994], [-13892, -125094], [-17092, -125094], [-17092, -121244], [-22192, -121244], [-22192, -123944], [-22392, -123944], [-22392, -125844], [-23492, -125844], [-23492, -125094], [-26892, -125094], [-26892, -125994]], [[-27907, 61769], [-28407, 61769], [-28407, 61170], [-31507, 61170], [-31507, 60270], [-39207, 60270], [-39207, 61770], [-40007, 61770], [-40007, 61170], [-44607, 61170], [-44607, 61770], [-45407, 61770], [-45407, 60270], [-53107, 60270], [-53107, 61170], [-56207, 61170], [-56207, 61770], [-56707, 61770], [-56707, 69671], [-46307, 69670], [-46307, 69970], [-45807, 69970], [-45807, 72270], [-45107, 72270], [-45107, 73520], [-40507, 73520], [-40507, 72670], [-38307, 72670], [-38307, 69670], [-27907, 69670]], [[-140590, -126217], [-140589, -133617], [-139990, -133617], [-139990, -134217], [-137190, -134217], [-137190, -135117], [-130590, -135117], [-130590, -134717], [-129190, -134717], [-129190, -135117], [-123490, -135117], [-123490, -134197], [-120890, -134197], [-120890, -133617], [-119891, -133617], [-119891, -134197], [-117290, -134197], [-117290, -135117], [-111591, -135117], [-111591, -134717], [-110191, -134717], [-110191, -135117], [-103591, -135117], [-103591, -134217], [-100790, -134217], [-100790, -133617], [-100191, -133617], [-100191, -126217], [-106591, -126217], [-106591, -119067], [-106391, -119067], [-106391, -118667], [-112091, -118667], [-112091, -119917], [-114391, -119917], [-114391, -123817], [-115741, -123817], [-115741, -124817], [-115190, -124817], [-115190, -126617], [-125590, -126617], [-125590, -124817], [-124940, -124817], [-124940, -123817], [-126290, -123817], [-126290, -120017], [-128990, -120017], [-128990, -118667], [-134190, -118667], [-134190, -126217]]], \"column\": [[[43364, 76052], [45764, 76052], [45764, 73152], [45214, 73152], [45214, 73352], [45564, 73352], [45564, 75852], [43564, 75852], [43564, 73352], [44114, 73352], [44114, 73152], [43364, 73152]], [[40664, 76052], [40864, 76052], [40864, 74402], [40664, 74402]], [[31804, 71302], [31804, 71102], [31164, 71102], [31164, 68402], [31864, 68402], [31864, 68202], [30964, 68202], [30964, 71302]], [[34764, 66002], [34764, 64002], [35164, 64002], [35164, 63802], [34564, 63802], [34564, 66002]], [[47065, 72202], [47585, 72202], [47585, 72002], [47265, 72002], [47265, 68752], [45965, 68752], [45965, 68202], [45765, 68202], [45765, 68952], [47065, 68952]], [[37464, 72202], [38214, 72202], [38214, 72002], [37664, 72002], [37664, 68202], [36829, 68202], [36829, 68402], [37464, 68402]], [[40664, 66002], [40864, 66002], [40864, 64002], [41564, 64002], [41564, 63802], [40364, 63802], [40364, 64002], [40664, 64002]], [[31164, 66002], [31164, 64002], [31664, 64002], [31664, 63802], [30964, 63802], [30964, 66002]], [[47064, 66002], [47264, 66002], [47264, 64002], [47564, 64002], [47564, 63802], [46364, 63802], [46364, 64002], [47064, 64002]], [[53165, 66002], [53365, 66002], [53365, 63802], [52765, 63802], [52765, 64002], [53165, 64002]], [[49715, 72202], [50465, 72202], [50465, 68402], [51100, 68402], [51100, 68202], [50265, 68202], [50265, 72002], [49715, 72002]], [[56125, 71302], [56965, 71302], [56965, 68202], [56065, 68202], [56065, 68402], [56765, 68402], [56765, 71102], [56125, 71102]], [[57095, 71302], [57935, 71302], [57935, 71102], [57295, 71102], [57295, 68402], [57995, 68402], [57995, 68202], [57095, 68202]], [[56765, 66002], [56965, 66002], [56965, 63802], [56265, 63802], [56265, 64002], [56765, 64002]], [[57095, 66002], [57295, 66002], [57295, 64002], [57795, 64002], [57795, 63802], [57095, 63802]], [[60694, 66002], [60894, 66002], [60894, 64002], [61294, 64002], [61294, 63802], [60694, 63802]], [[63595, 72202], [64345, 72202], [64345, 72002], [63795, 72002], [63795, 68202], [62960, 68202], [62960, 68402], [63595, 68402]], [[66795, 66002], [66995, 66002], [66995, 64002], [67695, 64002], [67695, 63802], [66495, 63802], [66495, 64002], [66795, 64002]], [[66475, 72202], [66995, 72202], [66995, 68952], [68295, 68952], [68295, 68202], [68095, 68202], [68095, 68752], [66795, 68752], [66795, 72002], [66475, 72002]], [[68295, 76052], [70695, 76052], [70695, 73152], [69945, 73152], [69945, 73352], [70495, 73352], [70495, 75852], [68495, 75852], [68495, 73352], [68845, 73352], [68845, 73152], [68295, 73152]], [[73195, 76052], [73395, 76052], [73395, 74402], [73195, 74402]], [[73195, 66002], [73395, 66002], [73395, 64002], [73695, 64002], [73695, 63802], [72495, 63802], [72495, 64002], [73195, 64002]], [[75845, 72202], [76595, 72202], [76595, 68402], [77230, 68402], [77230, 68202], [76395, 68202], [76395, 72002], [75845, 72002]], [[71045, 71102], [73195, 71102], [73195, 72202], [73725, 72202], [73725, 72002], [73395, 72002], [73395, 68752], [71245, 68752], [71245, 68202], [71045, 68202], [71045, 69402], [71245, 69402], [71245, 68952], [73195, 68952], [73195, 70902], [71245, 70902], [71245, 70402], [71045, 70402]], [[79295, 66002], [79495, 66002], [79495, 63802], [78895, 63802], [78895, 64002], [79295, 64002]], [[82895, 66002], [83095, 66002], [83095, 63802], [82395, 63802], [82395, 64002], [82895, 64002]], [[37384, -15012], [38134, -15012], [38134, -15212], [37584, -15212], [37584, -19012], [36749, -19012], [36749, -18812], [37384, -18812]], [[82255, 71302], [83095, 71302], [83095, 68202], [82195, 68202], [82195, 68402], [82895, 68402], [82895, 71102], [82255, 71102]], [[40584, -11162], [40784, -11162], [40784, -12812], [40584, -12812]], [[31724, -15912], [31724, -16112], [31084, -16112], [31084, -18812], [31784, -18812], [31784, -19012], [30884, -19012], [30884, -15912]], [[34684, -21211], [34684, -23211], [35084, -23211], [35084, -23411], [34484, -23411], [34484, -21211]], [[40254, -15012], [40784, -15012], [40784, -16112], [42934, -16112], [42934, -16812], [42734, -16812], [42734, -16312], [40784, -16312], [40784, -18262], [42734, -18262], [42734, -17812], [42934, -17812], [42934, -19012], [42734, -19012], [42734, -18462], [40584, -18462], [40584, -15212], [40254, -15212]], [[43284, -11162], [45684, -11162], [45684, -14062], [45134, -14062], [45134, -13862], [45484, -13862], [45484, -11362], [43484, -11362], [43484, -13862], [44034, -13862], [44034, -14062], [43284, -14062]], [[40585, -21211], [40785, -21211], [40785, -23211], [41485, -23211], [41485, -23411], [40285, -23411], [40285, -23211], [40585, -23211]], [[31084, -21212], [31084, -23212], [31584, -23212], [31584, -23412], [30884, -23412], [30884, -21212]], [[46985, -15012], [47505, -15012], [47505, -15212], [47185, -15212], [47185, -18462], [45885, -18462], [45885, -19012], [45685, -19012], [45685, -18262], [46985, -18262]], [[46985, -21211], [47185, -21211], [47185, -23211], [47485, -23211], [47485, -23411], [46285, -23411], [46285, -23211], [46985, -23211]], [[53085, -21211], [53285, -21211], [53285, -23411], [52685, -23411], [52685, -23211], [53085, -23211]], [[49635, -15012], [50385, -15012], [50385, -18812], [51020, -18812], [51020, -19012], [50185, -19012], [50185, -15212], [49635, -15212]], [[56045, -15912], [56885, -15912], [56885, -19012], [55985, -19012], [55985, -18812], [56685, -18812], [56685, -16112], [56045, -16112]], [[56685, -21212], [56885, -21212], [56885, -23412], [56185, -23412], [56185, -23212], [56685, -23212]], [[57014, -15912], [57854, -15912], [57854, -16112], [57214, -16112], [57214, -18812], [57914, -18812], [57914, -19012], [57014, -19012]], [[57014, -21212], [57214, -21212], [57214, -23212], [57714, -23212], [57714, -23412], [57014, -23412]], [[60614, -21211], [60814, -21211], [60814, -23211], [61214, -23211], [61214, -23411], [60614, -23411]], [[63514, -15012], [64264, -15012], [64264, -15212], [63714, -15212], [63714, -19012], [62879, -19012], [62879, -18812], [63514, -18812]], [[66394, -15012], [66914, -15012], [66914, -18262], [68214, -18262], [68214, -19012], [68014, -19012], [68014, -18462], [66714, -18462], [66714, -15212], [66394, -15212]], [[66714, -21211], [66914, -21211], [66914, -23211], [67614, -23211], [67614, -23411], [66414, -23411], [66414, -23211], [66714, -23211]], [[68215, -11162], [70615, -11162], [70615, -14062], [69865, -14062], [69865, -13862], [70415, -13862], [70415, -11362], [68415, -11362], [68415, -13862], [68765, -13862], [68765, -14062], [68215, -14062]], [[73115, -11162], [73315, -11162], [73315, -12812], [73115, -12812]], [[72414, -23211], [73114, -23211], [73114, -21211], [73314, -21211], [73314, -23211], [73614, -23211], [73614, -23411], [72414, -23411]], [[40334, 72202], [40864, 72202], [40864, 71102], [43014, 71102], [43014, 70402], [42814, 70402], [42814, 70902], [40864, 70902], [40864, 68952], [42814, 68952], [42814, 69402], [43014, 69402], [43014, 68202], [42814, 68202], [42814, 68752], [40664, 68752], [40664, 72002], [40334, 72002]], [[75765, -15012], [76515, -15012], [76515, -18812], [77150, -18812], [77150, -19012], [76315, -19012], [76315, -15212], [75765, -15212]], [[79215, -21211], [79415, -21211], [79415, -23411], [78815, -23411], [78815, -23211], [79215, -23211]], [[82315, -23212], [82815, -23212], [82815, -21212], [83015, -21212], [83015, -23412], [82315, -23412]], [[-4262, -64971], [-4262, -65171], [-4902, -65171], [-4902, -67871], [-4202, -67871], [-4202, -68071], [-5102, -68071], [-5102, -64971]], [[70965, -16112], [73115, -16112], [73115, -15012], [73645, -15012], [73645, -15212], [73315, -15212], [73315, -18462], [71165, -18462], [71165, -19012], [70965, -19012], [70965, -17812], [71165, -17812], [71165, -18262], [73115, -18262], [73115, -16312], [71165, -16312], [71165, -16812], [70965, -16812]], [[1397, -64071], [2147, -64071], [2147, -64271], [1597, -64271], [1597, -68071], [762, -68071], [762, -67871], [1397, -67871]], [[-4902, -70271], [-4902, -72271], [-4402, -72271], [-4402, -72471], [-5102, -72471], [-5102, -70271]], [[-1502, -70271], [-1302, -70271], [-1302, -72271], [-902, -72271], [-902, -72471], [-1502, -72471]], [[4277, -64071], [4797, -64071], [4797, -67321], [6097, -67321], [6097, -68071], [5897, -68071], [5897, -67521], [4597, -67521], [4597, -64271], [4277, -64271]], [[4597, -70271], [4797, -70271], [4797, -72271], [5497, -72271], [5497, -72471], [4297, -72471], [4297, -72271], [4597, -72271]], [[6098, -60221], [8498, -60221], [8498, -63121], [7748, -63121], [7748, -62921], [8298, -62921], [8298, -60421], [6298, -60421], [6298, -62921], [6648, -62921], [6648, -63121], [6098, -63121]], [[10998, -60221], [11198, -60221], [11198, -61871], [10998, -61871]], [[8848, -65171], [10998, -65171], [10998, -64071], [11528, -64071], [11528, -64271], [11198, -64271], [11198, -67521], [9048, -67521], [9048, -68071], [8848, -68071], [8848, -66871], [9048, -66871], [9048, -67321], [10998, -67321], [10998, -65371], [9048, -65371], [9048, -65871], [8848, -65871]], [[10997, -70271], [11197, -70271], [11197, -72271], [11497, -72271], [11497, -72471], [10297, -72471], [10297, -72271], [10997, -72271]], [[13648, -64071], [14398, -64071], [14398, -67871], [15033, -67871], [15033, -68071], [14198, -68071], [14198, -64271], [13648, -64271]], [[17098, -70271], [17298, -70271], [17298, -72471], [16698, -72471], [16698, -72271], [17098, -72271]], [[20058, -64971], [20898, -64971], [20898, -68071], [19998, -68071], [19998, -67871], [20698, -67871], [20698, -65171], [20058, -65171]], [[82175, -15912], [83015, -15912], [83015, -19012], [82115, -19012], [82115, -18812], [82815, -18812], [82815, -16112], [82175, -16112]], [[20698, -70271], [20898, -70271], [20898, -72471], [20198, -72471], [20198, -72271], [20698, -72271]], [[-19441, -126194], [-17291, -126194], [-17291, -125094], [-16761, -125094], [-16761, -125294], [-17091, -125294], [-17091, -128544], [-19241, -128544], [-19241, -129094], [-19441, -129094], [-19441, -127894], [-19241, -127894], [-19241, -128344], [-17291, -128344], [-17291, -126394], [-19241, -126394], [-19241, -126894], [-19441, -126894]], [[-22192, -128344], [-22192, -129095], [-22392, -129095], [-22392, -128544], [-23692, -128544], [-23692, -125294], [-24012, -125294], [-24012, -125094], [-23492, -125094], [-23492, -128344]], [[-17291, -122895], [-17291, -121245], [-17091, -121245], [-17091, -122895]], [[-20541, -124145], [-20541, -123945], [-19991, -123945], [-19991, -121445], [-21991, -121445], [-21991, -123945], [-21641, -123945], [-21641, -124145], [-22191, -124145], [-22191, -121245], [-19791, -121245], [-19791, -124145]], [[-23491, -131294], [-23491, -133294], [-22791, -133294], [-22791, -133494], [-23991, -133494], [-23991, -133294], [-23691, -133294], [-23691, -131294]], [[-17291, -131294], [-17091, -131294], [-17091, -133294], [-16791, -133294], [-16791, -133494], [-17991, -133494], [-17991, -133294], [-17291, -133294]], [[-26142, -125294], [-26692, -125294], [-26692, -129094], [-27527, -129094], [-27527, -128894], [-26892, -128894], [-26892, -125094], [-26142, -125094]], [[-29592, -131294], [-29592, -133294], [-29192, -133294], [-29192, -133494], [-29792, -133494], [-29792, -131294]], [[-14641, -125294], [-14641, -125094], [-13891, -125094], [-13891, -128894], [-13256, -128894], [-13256, -129094], [-14091, -129094], [-14091, -125294]], [[-11191, -131294], [-10991, -131294], [-10991, -133494], [-11591, -133494], [-11591, -133294], [-11191, -133294]], [[-8231, -126194], [-8231, -125994], [-7391, -125994], [-7391, -129094], [-8291, -129094], [-8291, -128894], [-7591, -128894], [-7591, -126194]], [[-32552, -126194], [-33192, -126194], [-33192, -128894], [-32492, -128894], [-32492, -129094], [-33392, -129094], [-33392, -125994], [-32552, -125994]], [[-33192, -131294], [-33192, -133294], [-32692, -133294], [-32692, -133494], [-33392, -133494], [-33392, -131294]], [[-7591, -131294], [-7391, -131294], [-7391, -133494], [-8091, -133494], [-8091, -133294], [-7591, -133294]], [[-26892, -125094], [-26142, -125094], [-26142, -125294], [-26692, -125294], [-26692, -129094], [-27527, -129094], [-27527, -128894], [-26892, -128894]], [[-32552, -125994], [-32552, -126194], [-33192, -126194], [-33192, -128894], [-32492, -128894], [-32492, -129094], [-33392, -129094], [-33392, -125994]], [[-29592, -131294], [-29592, -133294], [-29192, -133294], [-29192, -133494], [-29792, -133494], [-29792, -131294]], [[-22191, -124145], [-22191, -121245], [-19791, -121245], [-19791, -124145], [-20541, -124145], [-20541, -123945], [-19991, -123945], [-19991, -121445], [-21991, -121445], [-21991, -123945], [-21641, -123945], [-21641, -124145]], [[-33192, -131294], [-33192, -133294], [-32692, -133294], [-32692, -133494], [-33392, -133494], [-33392, -131294]], [[-17291, -122895], [-17291, -121245], [-17091, -121245], [-17091, -122895]], [[-23691, -131294], [-23491, -131294], [-23491, -133294], [-22791, -133294], [-22791, -133494], [-23991, -133494], [-23991, -133294], [-23691, -133294]], [[-17291, -131294], [-17091, -131294], [-17091, -133294], [-16791, -133294], [-16791, -133494], [-17991, -133494], [-17991, -133294], [-17291, -133294]], [[-14641, -125094], [-13891, -125094], [-13891, -128894], [-13256, -128894], [-13256, -129094], [-14091, -129094], [-14091, -125294], [-14641, -125294]], [[-11191, -131294], [-10991, -131294], [-10991, -133494], [-11591, -133494], [-11591, -133294], [-11191, -133294]], [[-8231, -125994], [-7391, -125994], [-7391, -129094], [-8291, -129094], [-8291, -128894], [-7591, -128894], [-7591, -126194], [-8231, -126194]], [[-7591, -131294], [-7391, -131294], [-7391, -133494], [-8091, -133494], [-8091, -133294], [-7591, -133294]], [[-63400, -31835], [-63400, -32834], [-63400, -35634], [-62770, -35634], [-62770, -35834], [-63600, -35834], [-63600, -32834], [-63600, -32035], [-64050, -32035], [-64050, -31835]], [[-57740, -32734], [-56900, -32734], [-56900, -35834], [-57800, -35834], [-57800, -35634], [-57100, -35634], [-57100, -32934], [-57740, -32934]], [[-66300, -31835], [-66300, -32035], [-66600, -32035], [-66600, -33035], [-66600, -35285], [-68750, -35285], [-68750, -35834], [-68950, -35834], [-68950, -35185], [-68950, -34610], [-68750, -34610], [-68750, -35085], [-66800, -35085], [-66800, -33135], [-68750, -33135], [-68750, -33610], [-68950, -33610], [-68950, -33135], [-69500, -33135], [-69500, -32935], [-68850, -32935], [-66800, -32935], [-66800, -31835]], [[-66600, -29885], [-66800, -29885], [-66800, -27985], [-66600, -27985]], [[-60699, -38335], [-60499, -38335], [-60499, -40235], [-61100, -40235], [-61100, -40035], [-60699, -40035]], [[-69300, -30885], [-69950, -30885], [-69950, -30685], [-69500, -30685], [-69500, -28185], [-71500, -28185], [-71500, -30685], [-71050, -30685], [-71050, -30885], [-71600, -30885], [-71900, -30885], [-71900, -30685], [-71700, -30685], [-71700, -27985], [-69300, -27985]], [[-57100, -38035], [-56900, -38035], [-56900, -40235], [-57600, -40235], [-57600, -40035], [-57100, -40035]], [[-56750, -38034], [-56550, -38034], [-56550, -40035], [-56050, -40035], [-56050, -40235], [-56750, -40235]], [[-66600, -37435], [-66600, -40235], [-67500, -40235], [-67500, -40035], [-66800, -40035], [-66800, -37435]], [[-53850, -36535], [-52950, -36535], [-52950, -40035], [-52450, -40035], [-52450, -40235], [-53150, -40235], [-53150, -36735], [-53850, -36735]], [[-51590, -32335], [-50750, -32335], [-50750, -35235], [-50050, -35235], [-48950, -35235], [-48950, -35435], [-50050, -35435], [-50950, -35435], [-50950, -32535], [-51590, -32535]], [[-71700, -35085], [-71700, -35834], [-71900, -35834], [-71900, -35285], [-73200, -35285], [-73200, -33835], [-73200, -32785], [-73200, -32035], [-73600, -32035], [-73600, -31835], [-73000, -31835], [-73000, -32785], [-73000, -33835], [-73000, -35085]], [[-73000, -37435], [-73000, -40035], [-72300, -40035], [-72300, -40235], [-73200, -40235], [-73200, -37435]], [[-46350, -32035], [-45850, -32035], [-45850, -29735], [-45050, -29735], [-43350, -29735], [-43350, -32235], [-44050, -32235], [-44050, -32035], [-43550, -32035], [-43550, -29935], [-45050, -29935], [-45650, -29935], [-45650, -32035], [-45150, -32035], [-45150, -32235], [-45750, -32235], [-46150, -32235], [-46150, -32535], [-46350, -32535]], [[-75750, -31835], [-75750, -32035], [-76200, -32035], [-76200, -32834], [-76200, -35834], [-77030, -35834], [-77030, -35634], [-76400, -35634], [-76400, -32834], [-76400, -31835]], [[-46350, -33735], [-46150, -33735], [-46150, -35235], [-45550, -35235], [-45350, -35235], [-45350, -35435], [-45550, -35435], [-46350, -35435]], [[-45650, -37535], [-45450, -37535], [-45450, -40035], [-44450, -40035], [-44450, -40235], [-45650, -40235]], [[-79100, -38335], [-79100, -40035], [-78700, -40035], [-78700, -40235], [-79300, -40235], [-79300, -38335]], [[-40750, -29335], [-38350, -29335], [-38350, -32135], [-38350, -32535], [-38550, -32535], [-38550, -32235], [-39000, -32235], [-39000, -32035], [-38550, -32035], [-38550, -29535], [-40550, -29535], [-40550, -32035], [-40100, -32035], [-40100, -32235], [-40750, -32235]], [[-82060, -32734], [-82060, -32934], [-82700, -32934], [-82700, -35634], [-81999, -35634], [-81999, -35834], [-82900, -35834], [-82900, -32734]], [[-39350, -35235], [-39150, -35235], [-38550, -35235], [-38550, -33735], [-38350, -33735], [-38350, -35435], [-39150, -35435], [-39350, -35435]], [[-40249, -40035], [-39250, -40035], [-39250, -37535], [-39050, -37535], [-39050, -40235], [-40249, -40235]], [[-82700, -38035], [-82700, -40035], [-82200, -40035], [-82200, -40235], [-82900, -40235], [-82900, -38035]], [[-35750, -35235], [-34650, -35235], [-33950, -35235], [-33950, -32335], [-33110, -32335], [-33110, -32535], [-33750, -32535], [-33750, -35435], [-34650, -35435], [-35750, -35435]], [[-31750, -36535], [-30849, -36535], [-30849, -36735], [-31550, -36735], [-31550, -40235], [-32249, -40235], [-32249, -40035], [-31750, -40035]], [[-28790, -32335], [-27950, -32335], [-27950, -35435], [-28850, -35435], [-28850, -35235], [-28150, -35235], [-28150, -32535], [-28790, -32535]], [[-28150, -38035], [-27950, -38035], [-27950, -40235], [-28650, -40235], [-28650, -40035], [-28150, -40035]], [[-57697, 69070], [-57697, 69270], [-56857, 69270], [-56857, 66170], [-57757, 66170], [-57757, 66370], [-57057, 66370], [-57057, 69070]], [[-56707, 69669], [-55867, 69669], [-55867, 69469], [-56507, 69469], [-56507, 66769], [-55807, 66769], [-55807, 66569], [-56707, 66569]], [[-63357, 66370], [-62727, 66370], [-62727, 66170], [-63557, 66170], [-63557, 69170], [-63557, 69969], [-64007, 69969], [-64007, 70169], [-63357, 70169], [-63357, 69170]], [[-60457, 63669], [-60457, 61769], [-61057, 61769], [-61057, 61969], [-60657, 61969], [-60657, 63669]], [[-57057, 63969], [-56857, 63969], [-56857, 61769], [-57557, 61769], [-57557, 61969], [-57057, 61969]], [[-56707, 63970], [-56507, 63970], [-56507, 61969], [-56007, 61969], [-56007, 61769], [-56707, 61769]], [[-66257, 69969], [-66557, 69969], [-66557, 68969], [-66557, 66719], [-68707, 66719], [-68707, 66170], [-68907, 66170], [-68907, 66819], [-68907, 67394], [-68707, 67394], [-68707, 66919], [-66757, 66919], [-66757, 68869], [-68707, 68869], [-68707, 68394], [-68907, 68394], [-68907, 68869], [-69457, 68869], [-69457, 69069], [-68807, 69069], [-66757, 69069], [-66757, 70169], [-66257, 70169]], [[-53807, 65469], [-52907, 65469], [-52907, 61969], [-52407, 61969], [-52407, 61769], [-53107, 61769], [-53107, 65269], [-53807, 65269]], [[-66557, 64569], [-66557, 61769], [-67457, 61769], [-67457, 61969], [-66757, 61969], [-66757, 64569]], [[-66557, 72119], [-66757, 72119], [-66757, 74018], [-66557, 74018]], [[-51547, 69469], [-51547, 69669], [-50707, 69669], [-50707, 66769], [-50007, 66769], [-48907, 66769], [-48907, 66569], [-50007, 66569], [-50907, 66569], [-50907, 69469]], [[-69257, 71119], [-69907, 71119], [-69907, 71319], [-69457, 71319], [-69457, 73819], [-71457, 73819], [-71457, 71319], [-71007, 71319], [-71007, 71119], [-71557, 71119], [-71857, 71119], [-71857, 71319], [-71657, 71319], [-71657, 74019], [-69257, 74019]], [[-71657, 66919], [-71657, 66170], [-71857, 66170], [-71857, 66719], [-73157, 66719], [-73157, 68169], [-73157, 69219], [-73157, 69969], [-73557, 69969], [-73557, 70169], [-72957, 70169], [-72957, 69219], [-72957, 68169], [-72957, 66919]], [[-72957, 64569], [-72957, 61969], [-72257, 61969], [-72257, 61769], [-73157, 61769], [-73157, 64569]], [[-46307, 68269], [-46107, 68269], [-46107, 66769], [-45507, 66769], [-45307, 66769], [-45307, 66569], [-45507, 66569], [-46307, 66569]], [[-46307, 69469], [-46307, 69969], [-45807, 69969], [-45807, 72269], [-45007, 72269], [-43307, 72269], [-43307, 69769], [-44007, 69769], [-44007, 69969], [-43507, 69969], [-43507, 72069], [-45007, 72069], [-45607, 72069], [-45607, 69969], [-45107, 69969], [-45107, 69769], [-45707, 69769], [-46107, 69769], [-46107, 69469]], [[-45607, 64469], [-45407, 64469], [-45407, 61969], [-44407, 61969], [-44407, 61769], [-45607, 61769]], [[-75707, 69969], [-76157, 69969], [-76157, 69170], [-76157, 66170], [-76987, 66170], [-76987, 66370], [-76357, 66370], [-76357, 69170], [-76357, 70169], [-75707, 70169]], [[-40707, 69769], [-40707, 72669], [-38307, 72669], [-38307, 69869], [-38307, 69469], [-38507, 69469], [-38507, 69769], [-38957, 69769], [-38957, 69969], [-38507, 69969], [-38507, 72469], [-40507, 72469], [-40507, 69969], [-40057, 69969], [-40057, 69769]], [[-79057, 63669], [-79057, 61969], [-78657, 61969], [-78657, 61769], [-79257, 61769], [-79257, 63669]], [[-39307, 66769], [-39107, 66769], [-38507, 66769], [-38507, 68269], [-38307, 68269], [-38307, 66569], [-39107, 66569], [-39307, 66569]], [[-40207, 61969], [-39207, 61969], [-39207, 64469], [-39007, 64469], [-39007, 61769], [-40207, 61769]], [[-82017, 69070], [-82657, 69070], [-82657, 66370], [-81957, 66370], [-81957, 66170], [-82857, 66170], [-82857, 69270], [-82017, 69270]], [[-82157, 61969], [-82157, 61769], [-82857, 61769], [-82857, 63969], [-82657, 63969], [-82657, 61969]], [[-35707, 66769], [-34607, 66769], [-33907, 66769], [-33907, 69669], [-33067, 69669], [-33067, 69469], [-33707, 69469], [-33707, 66569], [-34607, 66569], [-35707, 66569]], [[-31707, 65469], [-30806, 65469], [-30806, 65269], [-31507, 65269], [-31507, 61769], [-32207, 61769], [-32207, 61969], [-31707, 61969]], [[-28807, 66769], [-28107, 66769], [-28107, 69469], [-28747, 69469], [-28747, 69669], [-27907, 69669], [-27907, 66569], [-28807, 66569]], [[-28607, 61969], [-28107, 61969], [-28107, 63969], [-27907, 63969], [-27907, 61769], [-28607, 61769]], [[-108894, 110646], [-108319, 110646], [-108319, 108346], [-108069, 108346], [-108069, 110646], [-107494, 110646], [-107494, 110846], [-108194, 110846], [-108894, 110846]], [[-114194, 104096], [-114394, 104096], [-114394, 103846], [-114094, 103846], [-113794, 103846], [-113794, 104096], [-113994, 104096], [-113994, 107096], [-114194, 107096]], [[-102394, 104096], [-102594, 104096], [-102594, 103846], [-102294, 103846], [-101994, 103846], [-101994, 104096], [-102194, 104096], [-102194, 107096], [-102394, 107096]], [[-88194, 104096], [-88794, 104096], [-88794, 103846], [-87994, 103846], [-87994, 105546], [-88194, 105546]], [[-94594, 103846], [-93794, 103846], [-93794, 104096], [-94344, 104096], [-94344, 106896], [-94594, 106896]], [[-98794, 103846], [-97794, 103846], [-97794, 104096], [-98594, 104096], [-98594, 107096], [-98794, 107096]], [[-108319, 104096], [-108894, 104096], [-108894, 103846], [-108194, 103846], [-107494, 103846], [-107494, 104096], [-108069, 104096], [-108069, 107096], [-108319, 107096]], [[-117794, 104096], [-118594, 104096], [-118594, 103846], [-117594, 103846], [-117594, 107096], [-117794, 107096]], [[-122044, 104096], [-122594, 104096], [-122594, 103846], [-121794, 103846], [-121794, 106896], [-122044, 106896]], [[-128394, 103846], [-127594, 103846], [-127594, 104096], [-128194, 104096], [-128194, 105546], [-128394, 105546]], [[-88834, 111046], [-88194, 111046], [-88194, 108346], [-88594, 108346], [-88594, 108146], [-87994, 108146], [-87994, 111246], [-88834, 111246]], [[-94594, 111246], [-94594, 108146], [-93994, 108146], [-93994, 108346], [-94394, 108346], [-94394, 111046], [-93754, 111046], [-93754, 111246]], [[-122634, 111046], [-121994, 111046], [-121994, 108346], [-122394, 108346], [-122394, 108146], [-121794, 108146], [-121794, 111246], [-122634, 111246]], [[-128394, 111246], [-128394, 108146], [-127794, 108146], [-127794, 108346], [-128194, 108346], [-128194, 111046], [-127554, 111046], [-127554, 111246]], [[-102994, 110646], [-102394, 110646], [-102394, 108346], [-102194, 108346], [-102194, 110846], [-102994, 110846]], [[-113994, 108346], [-113994, 110646], [-113394, 110646], [-113394, 110846], [-114194, 110846], [-114194, 108346]], [[-98794, 111246], [-98594, 111246], [-98594, 113546], [-98494, 113546], [-98494, 113746], [-98794, 113746]], [[-117894, 113546], [-117794, 113546], [-117794, 111246], [-117594, 111246], [-117594, 112746], [-117594, 113746], [-117894, 113746]], [[-103544, 112646], [-102894, 112646], [-102094, 112646], [-101844, 112646], [-101844, 112846], [-102094, 112846], [-102894, 112846], [-103344, 112846], [-103344, 113646], [-103544, 113646]], [[-112944, 112846], [-113494, 112846], [-114194, 112846], [-114444, 112846], [-114444, 112646], [-114194, 112646], [-113494, 112646], [-112744, 112646], [-112744, 113646], [-112944, 113646]], [[-94594, 113746], [-94994, 113746], [-94994, 113546], [-94394, 113546], [-94394, 115246], [-94594, 115246]], [[-121994, 113546], [-121394, 113546], [-121394, 113746], [-121794, 113746], [-121794, 115246], [-121994, 115246]], [[-101994, 117346], [-99894, 117346], [-99894, 116846], [-99694, 116846], [-99694, 117446], [-99694, 118596], [-99494, 118596], [-99494, 118796], [-99894, 118796], [-99894, 117546], [-102194, 117546], [-102194, 115046], [-99694, 115046], [-99694, 115746], [-99894, 115746], [-99894, 115246], [-101994, 115246]], [[-117234, 118596], [-116994, 118596], [-116994, 117346], [-116994, 116796], [-116794, 116796], [-116794, 117246], [-114294, 117246], [-114294, 115246], [-116794, 115246], [-116794, 115696], [-116994, 115696], [-116994, 115046], [-114094, 115046], [-114094, 117446], [-116794, 117446], [-116794, 118796], [-117234, 118796]], [[-121794, 118796], [-122194, 118796], [-122194, 118396], [-121794, 118396]], [[-94194, 118796], [-94594, 118796], [-94594, 118396], [-94194, 118396]], [[-107894, 113646], [-108494, 113646], [-108494, 113246], [-107894, 113246]], [[-108094, 113246], [-107894, 113246], [-107894, 113446]], [[-108494, 113446], [-108494, 113400]], [[7443, 99135], [8018, 99135], [8018, 96835], [8268, 96835], [8268, 99135], [8843, 99135], [8843, 99335], [8143, 99335], [7443, 99335]], [[2143, 92585], [1943, 92585], [1943, 92335], [2243, 92335], [2543, 92335], [2543, 92585], [2343, 92585], [2343, 95585], [2143, 95585]], [[13943, 92585], [13743, 92585], [13743, 92335], [14043, 92335], [14343, 92335], [14343, 92585], [14143, 92585], [14143, 95585], [13943, 95585]], [[28143, 92585], [27543, 92585], [27543, 92335], [28343, 92335], [28343, 94035], [28143, 94035]], [[21743, 92335], [22543, 92335], [22543, 92585], [21993, 92585], [21993, 95385], [21743, 95385]], [[17543, 92335], [18543, 92335], [18543, 92585], [17743, 92585], [17743, 95585], [17543, 95585]], [[8018, 92585], [7443, 92585], [7443, 92335], [8143, 92335], [8843, 92335], [8843, 92585], [8268, 92585], [8268, 95585], [8018, 95585]], [[-1456, 92585], [-2256, 92585], [-2256, 92335], [-1256, 92335], [-1256, 95585], [-1456, 95585]], [[-5706, 92585], [-6256, 92585], [-6256, 92335], [-5456, 92335], [-5456, 95385], [-5706, 95385]], [[-12056, 92335], [-11256, 92335], [-11256, 92585], [-11856, 92585], [-11856, 94035], [-12056, 94035]], [[27503, 99535], [28143, 99535], [28143, 96835], [27743, 96835], [27743, 96635], [28343, 96635], [28343, 99735], [27503, 99735]], [[21743, 99735], [21743, 96635], [22343, 96635], [22343, 96835], [21943, 96835], [21943, 99535], [22583, 99535], [22583, 99735]], [[-6296, 99535], [-5656, 99535], [-5656, 96835], [-6056, 96835], [-6056, 96635], [-5456, 96635], [-5456, 99735], [-6296, 99735]], [[-12056, 99735], [-12056, 96635], [-11456, 96635], [-11456, 96835], [-11856, 96835], [-11856, 99535], [-11216, 99535], [-11216, 99735]], [[13343, 99135], [13943, 99135], [13943, 96835], [14143, 96835], [14143, 99335], [13343, 99335]], [[2343, 96835], [2343, 99135], [2943, 99135], [2943, 99335], [2143, 99335], [2143, 96835]], [[17543, 99735], [17743, 99735], [17743, 102035], [17843, 102035], [17843, 102235], [17543, 102235]], [[-1556, 102035], [-1456, 102035], [-1456, 99735], [-1256, 99735], [-1256, 101235], [-1256, 102235], [-1556, 102235]], [[12793, 101135], [13443, 101135], [14243, 101135], [14493, 101135], [14493, 101335], [14243, 101335], [13443, 101335], [12993, 101335], [12993, 102135], [12793, 102135]], [[3393, 101335], [2843, 101335], [2143, 101335], [1893, 101335], [1893, 101135], [2143, 101135], [2843, 101135], [3593, 101135], [3593, 102135], [3393, 102135]], [[21743, 102235], [21343, 102235], [21343, 102035], [21943, 102035], [21943, 103735], [21743, 103735]], [[-5656, 102035], [-5056, 102035], [-5056, 102235], [-5456, 102235], [-5456, 103735], [-5656, 103735]], [[14343, 105835], [16443, 105835], [16443, 105335], [16643, 105335], [16643, 105935], [16643, 107085], [16843, 107085], [16843, 107285], [16443, 107285], [16443, 106035], [14143, 106035], [14143, 103535], [16643, 103535], [16643, 104235], [16443, 104235], [16443, 103735], [14343, 103735]], [[-896, 107085], [-656, 107085], [-656, 105835], [-656, 105285], [-456, 105285], [-456, 105735], [2043, 105735], [2043, 103735], [-456, 103735], [-456, 104185], [-656, 104185], [-656, 103535], [2243, 103535], [2243, 105935], [-456, 105935], [-456, 107285], [-896, 107285]], [[-5456, 107285], [-5856, 107285], [-5856, 106885], [-5456, 106885]], [[22143, 107285], [21743, 107285], [21743, 106885], [22143, 106885]], [[8443, 102135], [7843, 102135], [7843, 101735], [8443, 101735]], [[8243, 101735], [8443, 101735], [8443, 101935]], [[7843, 101935], [7843, 101889]], [[116391, 110444], [116966, 110444], [116966, 108144], [117216, 108144], [117216, 110444], [117791, 110444], [117791, 110644], [117091, 110644], [116391, 110644]], [[111091, 103894], [110891, 103894], [110891, 103644], [111191, 103644], [111491, 103644], [111491, 103894], [111291, 103894], [111291, 106894], [111091, 106894]], [[122891, 103894], [122691, 103894], [122691, 103644], [122991, 103644], [123291, 103644], [123291, 103894], [123091, 103894], [123091, 106894], [122891, 106894]], [[137091, 103894], [136491, 103894], [136491, 103644], [137291, 103644], [137291, 105344], [137091, 105344]], [[130691, 103644], [131491, 103644], [131491, 103894], [130941, 103894], [130941, 106694], [130691, 106694]], [[126491, 103644], [127491, 103644], [127491, 103894], [126691, 103894], [126691, 106894], [126491, 106894]], [[116966, 103894], [116391, 103894], [116391, 103644], [117091, 103644], [117791, 103644], [117791, 103894], [117216, 103894], [117216, 106894], [116966, 106894]], [[107491, 103894], [106691, 103894], [106691, 103644], [107691, 103644], [107691, 106894], [107491, 106894]], [[103241, 103894], [102691, 103894], [102691, 103644], [103491, 103644], [103491, 106694], [103241, 106694]], [[96891, 103644], [97691, 103644], [97691, 103894], [97091, 103894], [97091, 105344], [96891, 105344]], [[136451, 110844], [137091, 110844], [137091, 108144], [136691, 108144], [136691, 107944], [137291, 107944], [137291, 111044], [136451, 111044]], [[130691, 111044], [130691, 107944], [131291, 107944], [131291, 108144], [130891, 108144], [130891, 110844], [131531, 110844], [131531, 111044]], [[102651, 110844], [103291, 110844], [103291, 108144], [102891, 108144], [102891, 107944], [103491, 107944], [103491, 111044], [102651, 111044]], [[96891, 111044], [96891, 107944], [97491, 107944], [97491, 108144], [97091, 108144], [97091, 110844], [97731, 110844], [97731, 111044]], [[122291, 110444], [122891, 110444], [122891, 108144], [123091, 108144], [123091, 110644], [122291, 110644]], [[111291, 108144], [111291, 110444], [111891, 110444], [111891, 110644], [111091, 110644], [111091, 108144]], [[126491, 111044], [126691, 111044], [126691, 113344], [126791, 113344], [126791, 113544], [126491, 113544]], [[107391, 113344], [107491, 113344], [107491, 111044], [107691, 111044], [107691, 112544], [107691, 113544], [107391, 113544]], [[121741, 112444], [122391, 112444], [123191, 112444], [123441, 112444], [123441, 112644], [123191, 112644], [122391, 112644], [121941, 112644], [121941, 113444], [121741, 113444]], [[-56750, -32335], [-55910, -32335], [-55910, -32535], [-56550, -32535], [-56550, -35235], [-55849, -35235], [-55849, -35435], [-56750, -35435]], [[130691, 113544], [130291, 113544], [130291, 113344], [130891, 113344], [130891, 115044], [130691, 115044]], [[112341, 112644], [111791, 112644], [111091, 112644], [110841, 112644], [110841, 112444], [111091, 112444], [111791, 112444], [112541, 112444], [112541, 113444], [112341, 113444]], [[103291, 113344], [103891, 113344], [103891, 113544], [103491, 113544], [103491, 115044], [103291, 115044]], [[123291, 117144], [125391, 117144], [125391, 116644], [125591, 116644], [125591, 117244], [125591, 118394], [125791, 118394], [125791, 118594], [125391, 118594], [125391, 117344], [123091, 117344], [123091, 114844], [125591, 114844], [125591, 115544], [125391, 115544], [125391, 115044], [123291, 115044]], [[108051, 118394], [108291, 118394], [108291, 117144], [108291, 116594], [108491, 116594], [108491, 117044], [110991, 117044], [110991, 115044], [108491, 115044], [108491, 115494], [108291, 115494], [108291, 114844], [111191, 114844], [111191, 117244], [108491, 117244], [108491, 118594], [108051, 118594]], [[103491, 118594], [103091, 118594], [103091, 118194], [103491, 118194]], [[131091, 118594], [130691, 118594], [130691, 118194], [131091, 118194]], [[117191, 113044], [117391, 113044], [117391, 113244]], [[116791, 113244], [116791, 113198]], [[117391, 113444], [116791, 113444], [116791, 113044], [117391, 113044]], [[-4549, 17921], [-4549, 15021], [-5249, 15021], [-6349, 15021], [-6349, 14821], [-5249, 14821], [-4349, 14821], [-4349, 17721], [-3709, 17721], [-3709, 17921]], [[-16949, 18121], [-16949, 17721], [-16749, 17721], [-16749, 18021], [-16299, 18021], [-16299, 18221], [-16749, 18221], [-16749, 20721], [-14749, 20721], [-14749, 18221], [-15199, 18221], [-15199, 18021], [-14549, 18021], [-14549, 20921], [-16949, 20921], [-16949, 18121]], [[-11949, 18021], [-11199, 18021], [-11199, 18221], [-11749, 18221], [-11749, 20321], [-10249, 20321], [-9649, 20321], [-9649, 18221], [-10199, 18221], [-10199, 18021], [-9549, 18021], [-9149, 18021], [-9149, 17721], [-8949, 17721], [-8949, 18221], [-9449, 18221], [-9449, 20521], [-10249, 20521], [-11949, 20521]], [[-20649, 15021], [-21349, 15021], [-21349, 17921], [-22189, 17921], [-22189, 17721], [-21549, 17721], [-21549, 14821], [-20649, 14821], [-19549, 14821], [-19549, 15021]], [[-9149, 15021], [-9749, 15021], [-9949, 15021], [-9949, 14821], [-9749, 14821], [-8949, 14821], [-8949, 16521], [-9149, 16521]], [[1450, 17921], [610, 17921], [610, 17721], [1250, 17721], [1250, 15021], [550, 15021], [550, 14821], [1450, 14821]], [[-16949, 14821], [-16149, 14821], [-15949, 14821], [-15949, 15021], [-16149, 15021], [-16749, 15021], [-16749, 16521], [-16949, 16521]], [[-27349, 17921], [-27349, 14821], [-26449, 14821], [-26449, 15021], [-27149, 15021], [-27149, 17721], [-26509, 17721], [-26509, 17921]], [[-2349, 13721], [-2349, 10221], [-2849, 10221], [-2849, 10021], [-2149, 10021], [-2149, 13521], [-1449, 13521], [-1449, 13721]], [[-24450, 13521], [-23749, 13521], [-23749, 10021], [-23050, 10021], [-23050, 10221], [-23549, 10221], [-23549, 13721], [-24450, 13721]], [[1250, 10221], [750, 10221], [750, 10021], [1450, 10021], [1450, 12222], [1250, 12222]], [[-27349, 10021], [-26649, 10021], [-26649, 10221], [-27149, 10221], [-27149, 12221], [-27349, 12221]], [[-9849, 10221], [-10849, 10221], [-10849, 10021], [-9649, 10021], [-9649, 12721], [-9849, 12721]], [[-16049, 10221], [-16049, 12721], [-16249, 12721], [-16249, 10021], [-15049, 10021], [-15049, 10221]], [[20000, 18121], [20000, 20921], [17600, 20921], [17600, 18021], [18250, 18021], [18250, 18221], [17800, 18221], [17800, 20721], [19800, 20721], [19800, 18221], [19350, 18221], [19350, 18021], [19800, 18021], [19800, 17721], [20000, 17721], [20000, 18121]], [[6760, 17721], [7400, 17721], [7400, 14821], [8300, 14821], [9400, 14821], [9400, 15021], [8300, 15021], [7600, 15021], [7600, 17921], [6760, 17921]], [[12500, 20521], [12500, 18221], [12000, 18221], [12000, 17721], [12200, 17721], [12200, 18021], [12600, 18021], [13250, 18021], [13250, 18221], [12700, 18221], [12700, 20321], [13300, 20321], [14800, 20321], [14800, 18221], [14250, 18221], [14250, 18021], [15000, 18021], [15000, 20521], [13300, 20521]], [[22600, 14821], [23700, 14821], [24600, 14821], [24600, 17721], [25240, 17721], [25240, 17921], [24400, 17921], [24400, 15021], [23700, 15021], [22600, 15021]], [[12000, 14821], [12800, 14821], [13000, 14821], [13000, 15021], [12800, 15021], [12200, 15021], [12200, 16521], [12000, 16521]], [[1600, 17921], [1600, 14821], [2500, 14821], [2500, 15021], [1800, 15021], [1800, 17721], [2440, 17721], [2440, 17921]], [[5200, 13521], [5200, 10021], [5899, 10021], [5899, 10221], [5400, 10221], [5400, 13721], [4499, 13721], [4499, 13521]], [[29560, 17721], [30200, 17721], [30200, 15021], [29499, 15021], [29499, 14821], [30400, 14821], [30400, 17921], [29560, 17921]], [[19800, 15021], [19200, 15021], [19000, 15021], [19000, 14821], [19200, 14821], [20000, 14821], [20000, 16521], [19800, 16521]], [[26600, 13721], [26600, 10221], [26100, 10221], [26100, 10021], [26800, 10021], [26800, 13521], [27500, 13521], [27500, 13721]], [[1600, 10021], [2300, 10021], [2300, 10221], [1800, 10221], [1800, 12222], [1600, 12222]], [[30200, 10221], [29700, 10221], [29700, 10021], [30400, 10021], [30400, 12221], [30200, 12221]], [[19299, 10021], [19299, 12721], [19099, 12721], [19099, 10221], [18100, 10221], [18100, 10021]], [[12700, 10021], [13899, 10021], [13899, 10221], [12900, 10221], [12900, 12721], [12700, 12721]], [[-113175, 32860], [-112600, 32860], [-112600, 30560], [-112350, 30560], [-112350, 32860], [-111775, 32860], [-111775, 33060], [-112475, 33060], [-113175, 33060]], [[-92475, 26310], [-93075, 26310], [-93075, 26060], [-92275, 26060], [-92275, 27760], [-92475, 27760]], [[-118475, 26310], [-118675, 26310], [-118675, 26060], [-118375, 26060], [-118075, 26060], [-118075, 26310], [-118275, 26310], [-118275, 29310], [-118475, 29310]], [[-106675, 26310], [-106875, 26310], [-106875, 26060], [-106575, 26060], [-106275, 26060], [-106275, 26310], [-106475, 26310], [-106475, 29310], [-106675, 29310]], [[-98875, 26060], [-98075, 26060], [-98075, 26310], [-98625, 26310], [-98625, 29110], [-98875, 29110]], [[-103075, 26060], [-102075, 26060], [-102075, 26310], [-102875, 26310], [-102875, 29310], [-103075, 29310]], [[-112600, 26310], [-113175, 26310], [-113175, 26060], [-112475, 26060], [-111775, 26060], [-111775, 26310], [-112350, 26310], [-112350, 29310], [-112600, 29310]], [[-122075, 26310], [-122875, 26310], [-122875, 26060], [-121875, 26060], [-121875, 29310], [-122075, 29310]], [[-126325, 26310], [-126875, 26310], [-126875, 26060], [-126075, 26060], [-126075, 29110], [-126325, 29110]], [[-132675, 26060], [-131875, 26060], [-131875, 26310], [-132475, 26310], [-132475, 27760], [-132675, 27760]], [[-98875, 33460], [-98875, 30360], [-98275, 30360], [-98275, 30560], [-98675, 30560], [-98675, 33260], [-98035, 33260], [-98035, 33460]], [[-93115, 33260], [-92475, 33260], [-92475, 30560], [-92875, 30560], [-92875, 30360], [-92275, 30360], [-92275, 33460], [-93115, 33460]], [[-126915, 33260], [-126275, 33260], [-126275, 30560], [-126675, 30560], [-126675, 30360], [-126075, 30360], [-126075, 33460], [-126915, 33460]], [[-107275, 32860], [-106675, 32860], [-106675, 30560], [-106475, 30560], [-106475, 33060], [-107275, 33060]], [[-132675, 33460], [-132675, 30360], [-132075, 30360], [-132075, 30560], [-132475, 30560], [-132475, 33260], [-131835, 33260], [-131835, 33460]], [[-118275, 30560], [-118275, 32860], [-117675, 32860], [-117675, 33060], [-118475, 33060], [-118475, 30560]], [[-122175, 35760], [-122075, 35760], [-122075, 33460], [-121875, 33460], [-121875, 34960], [-121875, 35960], [-122175, 35960]], [[-103075, 33460], [-102875, 33460], [-102875, 35760], [-102775, 35760], [-102775, 35960], [-103075, 35960]], [[-107825, 34860], [-107175, 34860], [-106375, 34860], [-106125, 34860], [-106125, 35060], [-106375, 35060], [-107175, 35060], [-107625, 35060], [-107625, 35860], [-107825, 35860]], [[-98875, 35960], [-99275, 35960], [-99275, 35760], [-98675, 35760], [-98675, 37460], [-98875, 37460]], [[-117225, 35060], [-117775, 35060], [-118475, 35060], [-118725, 35060], [-118725, 34860], [-118475, 34860], [-117775, 34860], [-117025, 34860], [-117025, 35860], [-117225, 35860]], [[-126275, 35760], [-125675, 35760], [-125675, 35960], [-126075, 35960], [-126075, 37460], [-126275, 37460]], [[-126075, 41010], [-126475, 41010], [-126475, 40610], [-126075, 40610]], [[-106275, 39560], [-104175, 39560], [-104175, 39060], [-103975, 39060], [-103975, 39660], [-103975, 40810], [-103775, 40810], [-103775, 41010], [-104175, 41010], [-104175, 39760], [-106475, 39760], [-106475, 37260], [-103975, 37260], [-103975, 37960], [-104175, 37960], [-104175, 37460], [-106275, 37460]], [[-121515, 40810], [-121275, 40810], [-121275, 39560], [-121275, 39010], [-121075, 39010], [-121075, 39460], [-118575, 39460], [-118575, 37460], [-121075, 37460], [-121075, 37910], [-121275, 37910], [-121275, 37260], [-118375, 37260], [-118375, 39660], [-121075, 39660], [-121075, 41010], [-121515, 41010]], [[-98475, 41010], [-98875, 41010], [-98875, 40610], [-98475, 40610]], [[-112175, 35860], [-112775, 35860], [-112775, 35460], [-112175, 35460]], [[-112375, 35460], [-112175, 35460], [-112175, 35660]], [[-112775, 35660], [-112775, 35614]], [[-116758, -43798], [-116183, -43798], [-116183, -46098], [-115933, -46098], [-115933, -43798], [-115358, -43798], [-115358, -43598], [-116058, -43598], [-116758, -43598]], [[-122058, -50348], [-122258, -50348], [-122258, -50598], [-121958, -50598], [-121658, -50598], [-121658, -50348], [-121858, -50348], [-121858, -47348], [-122058, -47348]], [[-110258, -50348], [-110458, -50348], [-110458, -50598], [-110158, -50598], [-109858, -50598], [-109858, -50348], [-110058, -50348], [-110058, -47348], [-110258, -47348]], [[-96058, -50348], [-96658, -50348], [-96658, -50598], [-95858, -50598], [-95858, -48898], [-96058, -48898]], [[-106658, -50598], [-105658, -50598], [-105658, -50348], [-106458, -50348], [-106458, -47348], [-106658, -47348]], [[-102458, -50598], [-101658, -50598], [-101658, -50348], [-102208, -50348], [-102208, -47548], [-102458, -47548]], [[-116183, -50348], [-116758, -50348], [-116758, -50598], [-116058, -50598], [-115358, -50598], [-115358, -50348], [-115933, -50348], [-115933, -47348], [-116183, -47348]], [[-125658, -50348], [-126458, -50348], [-126458, -50598], [-125458, -50598], [-125458, -47348], [-125658, -47348]], [[-129908, -50348], [-130458, -50348], [-130458, -50598], [-129658, -50598], [-129658, -47548], [-129908, -47548]], [[-136258, -50598], [-135458, -50598], [-135458, -50348], [-136058, -50348], [-136058, -48898], [-136258, -48898]], [[-96698, -43398], [-96058, -43398], [-96058, -46098], [-96458, -46098], [-96458, -46298], [-95858, -46298], [-95858, -43198], [-96698, -43198]], [[-102458, -43198], [-102458, -46298], [-101858, -46298], [-101858, -46098], [-102258, -46098], [-102258, -43398], [-101618, -43398], [-101618, -43198]], [[-130498, -43398], [-129858, -43398], [-129858, -46098], [-130258, -46098], [-130258, -46298], [-129658, -46298], [-129658, -43198], [-130498, -43198]], [[-110858, -43798], [-110258, -43798], [-110258, -46098], [-110058, -46098], [-110058, -43598], [-110858, -43598]], [[-136258, -43198], [-136258, -46298], [-135658, -46298], [-135658, -46098], [-136058, -46098], [-136058, -43398], [-135418, -43398], [-135418, -43198]], [[-121858, -46098], [-121858, -43798], [-121258, -43798], [-121258, -43598], [-122058, -43598], [-122058, -46098]], [[-106658, -43198], [-106458, -43198], [-106458, -40898], [-106358, -40898], [-106358, -40698], [-106658, -40698]], [[-125758, -40898], [-125658, -40898], [-125658, -43198], [-125458, -43198], [-125458, -41698], [-125458, -40698], [-125758, -40698]], [[-102458, -40698], [-102858, -40698], [-102858, -40898], [-102258, -40898], [-102258, -39198], [-102458, -39198]], [[-111408, -41798], [-110758, -41798], [-109958, -41798], [-109708, -41798], [-109708, -41598], [-109958, -41598], [-110758, -41598], [-111208, -41598], [-111208, -40798], [-111408, -40798]], [[-120808, -41598], [-121358, -41598], [-122058, -41598], [-122308, -41598], [-122308, -41798], [-122058, -41798], [-121358, -41798], [-120608, -41798], [-120608, -40798], [-120808, -40798]], [[-129858, -40898], [-129258, -40898], [-129258, -40698], [-129658, -40698], [-129658, -39198], [-129858, -39198]], [[-129658, -35648], [-130058, -35648], [-130058, -36048], [-129658, -36048]], [[-109858, -37098], [-107758, -37098], [-107758, -37598], [-107558, -37598], [-107558, -36998], [-107558, -35848], [-107358, -35848], [-107358, -35648], [-107758, -35648], [-107758, -36898], [-110058, -36898], [-110058, -39398], [-107558, -39398], [-107558, -38698], [-107758, -38698], [-107758, -39198], [-109858, -39198]], [[-125098, -35848], [-124858, -35848], [-124858, -37098], [-124858, -37648], [-124658, -37648], [-124658, -37198], [-122158, -37198], [-122158, -39198], [-124658, -39198], [-124658, -38748], [-124858, -38748], [-124858, -39398], [-121958, -39398], [-121958, -36998], [-124658, -36998], [-124658, -35648], [-125098, -35648]], [[-102058, -35648], [-102458, -35648], [-102458, -36048], [-102058, -36048]], [[-115958, -41198], [-115758, -41198], [-115758, -40998]], [[-115758, -40798], [-116358, -40798], [-116358, -41198], [-115758, -41198]], [[-116358, -40998], [-116358, -41044]], [[116491, 38755], [117066, 38755], [117066, 36455], [117316, 36455], [117316, 38755], [117891, 38755], [117891, 38955], [117191, 38955], [116491, 38955]], [[111191, 32205], [110991, 32205], [110991, 31955], [111291, 31955], [111591, 31955], [111591, 32205], [111391, 32205], [111391, 35205], [111191, 35205]], [[122991, 32205], [122791, 32205], [122791, 31955], [123091, 31955], [123391, 31955], [123391, 32205], [123191, 32205], [123191, 35205], [122991, 35205]], [[130791, 31955], [131591, 31955], [131591, 32205], [131041, 32205], [131041, 35005], [130791, 35005]], [[137191, 32205], [136591, 32205], [136591, 31955], [137391, 31955], [137391, 33655], [137191, 33655]], [[126591, 31955], [127591, 31955], [127591, 32205], [126791, 32205], [126791, 35205], [126591, 35205]], [[107591, 32205], [106791, 32205], [106791, 31955], [107791, 31955], [107791, 35205], [107591, 35205]], [[103341, 32205], [102791, 32205], [102791, 31955], [103591, 31955], [103591, 35005], [103341, 35005]], [[117066, 32205], [116491, 32205], [116491, 31955], [117191, 31955], [117891, 31955], [117891, 32205], [117316, 32205], [117316, 35205], [117066, 35205]], [[96991, 31955], [97791, 31955], [97791, 32205], [97191, 32205], [97191, 33655], [96991, 33655]], [[136551, 39155], [137191, 39155], [137191, 36455], [136791, 36455], [136791, 36255], [137391, 36255], [137391, 39355], [136551, 39355]], [[130791, 39355], [130791, 36255], [131391, 36255], [131391, 36455], [130991, 36455], [130991, 39155], [131631, 39155], [131631, 39355]], [[102751, 39155], [103391, 39155], [103391, 36455], [102991, 36455], [102991, 36255], [103591, 36255], [103591, 39355], [102751, 39355]], [[122391, 38755], [122991, 38755], [122991, 36455], [123191, 36455], [123191, 38955], [122391, 38955]], [[96991, 39355], [96991, 36255], [97591, 36255], [97591, 36455], [97191, 36455], [97191, 39155], [97831, 39155], [97831, 39355]], [[111391, 36455], [111391, 38755], [111991, 38755], [111991, 38955], [111191, 38955], [111191, 36455]], [[126591, 39355], [126791, 39355], [126791, 41655], [126891, 41655], [126891, 41855], [126591, 41855]], [[107491, 41655], [107591, 41655], [107591, 39355], [107791, 39355], [107791, 40855], [107791, 41855], [107491, 41855]], [[121841, 40755], [122491, 40755], [123291, 40755], [123541, 40755], [123541, 40955], [123291, 40955], [122491, 40955], [122041, 40955], [122041, 41755], [121841, 41755]], [[130791, 41855], [130391, 41855], [130391, 41655], [130991, 41655], [130991, 43355], [130791, 43355]], [[112441, 40955], [111891, 40955], [111191, 40955], [110941, 40955], [110941, 40755], [111191, 40755], [111891, 40755], [112641, 40755], [112641, 41755], [112441, 41755]], [[103391, 41655], [103991, 41655], [103991, 41855], [103591, 41855], [103591, 43355], [103391, 43355]], [[123391, 45455], [125491, 45455], [125491, 44955], [125691, 44955], [125691, 45555], [125691, 46705], [125891, 46705], [125891, 46905], [125491, 46905], [125491, 45655], [123191, 45655], [123191, 43155], [125691, 43155], [125691, 43855], [125491, 43855], [125491, 43355], [123391, 43355]], [[103591, 46905], [103191, 46905], [103191, 46505], [103591, 46505]], [[108151, 46705], [108391, 46705], [108391, 45455], [108391, 44905], [108591, 44905], [108591, 45355], [111091, 45355], [111091, 43355], [108591, 43355], [108591, 43805], [108391, 43805], [108391, 43155], [111291, 43155], [111291, 45555], [108591, 45555], [108591, 46905], [108151, 46905]], [[117491, 41755], [116891, 41755], [116891, 41355], [117491, 41355]], [[131191, 46905], [130791, 46905], [130791, 46505], [131191, 46505]], [[117291, 41355], [117491, 41355], [117491, 41555]], [[116891, 41555], [116891, 41509]], [[-67491, -126534], [-66916, -126534], [-66916, -128834], [-66666, -128834], [-66666, -126534], [-66091, -126534], [-66091, -126334], [-66791, -126334], [-67491, -126334]], [[-72791, -133084], [-72991, -133084], [-72991, -133334], [-72691, -133334], [-72391, -133334], [-72391, -133084], [-72591, -133084], [-72591, -130084], [-72791, -130084]], [[-60991, -133084], [-61191, -133084], [-61191, -133334], [-60891, -133334], [-60591, -133334], [-60591, -133084], [-60791, -133084], [-60791, -130084], [-60991, -130084]], [[-46791, -133084], [-47391, -133084], [-47391, -133334], [-46591, -133334], [-46591, -131634], [-46791, -131634]], [[-53191, -133334], [-52391, -133334], [-52391, -133084], [-52941, -133084], [-52941, -130284], [-53191, -130284]], [[-57391, -133334], [-56391, -133334], [-56391, -133084], [-57191, -133084], [-57191, -130084], [-57391, -130084]], [[-76391, -133084], [-77191, -133084], [-77191, -133334], [-76191, -133334], [-76191, -130084], [-76391, -130084]], [[-66916, -133084], [-67491, -133084], [-67491, -133334], [-66791, -133334], [-66091, -133334], [-66091, -133084], [-66666, -133084], [-66666, -130084], [-66916, -130084]], [[-80641, -133084], [-81191, -133084], [-81191, -133334], [-80391, -133334], [-80391, -130284], [-80641, -130284]], [[-86991, -133334], [-86191, -133334], [-86191, -133084], [-86791, -133084], [-86791, -131634], [-86991, -131634]], [[-47431, -126134], [-46791, -126134], [-46791, -128834], [-47191, -128834], [-47191, -129034], [-46591, -129034], [-46591, -125934], [-47431, -125934]], [[-53191, -125934], [-53191, -129034], [-52591, -129034], [-52591, -128834], [-52991, -128834], [-52991, -126134], [-52351, -126134], [-52351, -125934]], [[-81231, -126134], [-80591, -126134], [-80591, -128834], [-80991, -128834], [-80991, -129034], [-80391, -129034], [-80391, -125934], [-81231, -125934]], [[-86991, -125934], [-86991, -129034], [-86391, -129034], [-86391, -128834], [-86791, -128834], [-86791, -126134], [-86151, -126134], [-86151, -125934]], [[-61591, -126534], [-60991, -126534], [-60991, -128834], [-60791, -128834], [-60791, -126334], [-61591, -126334]], [[-72591, -128834], [-72591, -126534], [-71991, -126534], [-71991, -126334], [-72791, -126334], [-72791, -128834]], [[-57391, -125934], [-57191, -125934], [-57191, -123634], [-57091, -123634], [-57091, -123434], [-57391, -123434]], [[-76491, -123634], [-76391, -123634], [-76391, -125934], [-76191, -125934], [-76191, -124434], [-76191, -123434], [-76491, -123434]], [[-53191, -123434], [-53591, -123434], [-53591, -123634], [-52991, -123634], [-52991, -121934], [-53191, -121934]], [[-62141, -124534], [-61491, -124534], [-60691, -124534], [-60441, -124534], [-60441, -124334], [-60691, -124334], [-61491, -124334], [-61941, -124334], [-61941, -123535], [-62141, -123535]], [[-71541, -124334], [-72091, -124334], [-72791, -124334], [-73041, -124334], [-73041, -124534], [-72791, -124534], [-72091, -124534], [-71341, -124534], [-71341, -123535], [-71541, -123535]], [[-80591, -123634], [-79991, -123634], [-79991, -123434], [-80391, -123434], [-80391, -121934], [-80591, -121934]], [[-80391, -118384], [-80791, -118384], [-80791, -118784], [-80391, -118784]], [[-60591, -119834], [-58491, -119834], [-58491, -120334], [-58291, -120334], [-58291, -119734], [-58291, -118584], [-58091, -118584], [-58091, -118384], [-58491, -118384], [-58491, -119634], [-60791, -119634], [-60791, -122134], [-58291, -122134], [-58291, -121434], [-58491, -121434], [-58491, -121934], [-60591, -121934]], [[-75831, -118584], [-75591, -118584], [-75591, -119834], [-75591, -120384], [-75391, -120384], [-75391, -119934], [-72891, -119934], [-72891, -121934], [-75391, -121934], [-75391, -121484], [-75591, -121484], [-75591, -122134], [-72691, -122134], [-72691, -119734], [-75391, -119734], [-75391, -118384], [-75831, -118384]], [[-52791, -118384], [-53191, -118384], [-53191, -118784], [-52791, -118784]], [[-66491, -123535], [-67091, -123535], [-67091, -123935], [-66491, -123935]], [[-67091, -123735], [-67091, -123781]], [[-66691, -123935], [-66491, -123935], [-66491, -123735]], [[28695, -121144], [28295, -121144], [28295, -121544], [28695, -121544]], [[25795, -121144], [25395, -121144], [25395, -121544], [25795, -121544]], [[26120, -127069], [26120, -126594], [27970, -126594], [27970, -127069], [28170, -127069], [28170, -126394], [25920, -126394], [25920, -127069]], [[14045, -128844], [14645, -128844], [14645, -128644], [14245, -128644], [14245, -125944], [14645, -125944], [14645, -125744], [14045, -125744]], [[20545, -125744], [20145, -125744], [20145, -125944], [20545, -125944], [20545, -128644], [20145, -128644], [20145, -128844], [20745, -128844], [20745, -125844], [20745, -125044], [21145, -125044], [21145, -124844], [20545, -124844]], [[25920, -128844], [26945, -128844], [27145, -128844], [28170, -128844], [28170, -128169], [27970, -128169], [27970, -128644], [27045, -128644], [26120, -128644], [26120, -128169], [25920, -128169]], [[33545, -124844], [32945, -124844], [32945, -125044], [33345, -125044], [33345, -125844], [33345, -128844], [33945, -128844], [33945, -128644], [33545, -128644], [33545, -125944], [33945, -125944], [33945, -125744], [33545, -125744]], [[39445, -125944], [39845, -125944], [39845, -128644], [39445, -128644], [39445, -128844], [40045, -128844], [40045, -125744], [39445, -125744]], [[14045, -133244], [14745, -133244], [14745, -133044], [14245, -133044], [14245, -131044], [14045, -131044]], [[17645, -133244], [18245, -133244], [18245, -133044], [17845, -133044], [17845, -131594], [17645, -131594]], [[36245, -133044], [35845, -133044], [35845, -133244], [36445, -133244], [36445, -131594], [36245, -131594]], [[39845, -133044], [39345, -133044], [39345, -133244], [40045, -133244], [40045, -131044], [39845, -131044]], [[23745, -124844], [23745, -126944], [23945, -126944], [23945, -125044], [24345, -125044], [24345, -124844]], [[30345, -124844], [29745, -124844], [29745, -125044], [30145, -125044], [30145, -126944], [30345, -126944]], [[23745, -133044], [23345, -133044], [23345, -133244], [23845, -133244], [24645, -133244], [24645, -133044], [23945, -133044], [23945, -131044], [23745, -131044]], [[30145, -133044], [29445, -133044], [29445, -133244], [30245, -133244], [30745, -133244], [30745, -133044], [30345, -133044], [30345, -131044], [30145, -131044]], [[-121090, -126817], [-120515, -126817], [-120515, -129117], [-120265, -129117], [-120265, -126817], [-119690, -126817], [-119690, -126617], [-120390, -126617], [-121090, -126617]], [[-126390, -133367], [-126590, -133367], [-126590, -133617], [-126290, -133617], [-125990, -133617], [-125990, -133367], [-126190, -133367], [-126190, -130367], [-126390, -130367]], [[-100390, -133367], [-100990, -133367], [-100990, -133617], [-100190, -133617], [-100190, -131917], [-100390, -131917]], [[-114590, -133367], [-114790, -133367], [-114790, -133617], [-114490, -133617], [-114190, -133617], [-114190, -133367], [-114390, -133367], [-114390, -130367], [-114590, -130367]], [[-106790, -133617], [-105990, -133617], [-105990, -133367], [-106540, -133367], [-106540, -130567], [-106790, -130567]], [[-110990, -133617], [-109990, -133617], [-109990, -133367], [-110790, -133367], [-110790, -130367], [-110990, -130367]], [[-120515, -133367], [-121090, -133367], [-121090, -133617], [-120390, -133617], [-119690, -133617], [-119690, -133367], [-120265, -133367], [-120265, -130367], [-120515, -130367]], [[-129990, -133367], [-130790, -133367], [-130790, -133617], [-129790, -133617], [-129790, -130367], [-129990, -130367]], [[-134240, -133367], [-134790, -133367], [-134790, -133617], [-133990, -133617], [-133990, -130567], [-134240, -130567]], [[-140590, -133617], [-139790, -133617], [-139790, -133367], [-140390, -133367], [-140390, -131917], [-140590, -131917]], [[-101030, -126417], [-100390, -126417], [-100390, -129117], [-100790, -129117], [-100790, -129317], [-100190, -129317], [-100190, -126217], [-101030, -126217]], [[-106790, -126217], [-106790, -129317], [-106190, -129317], [-106190, -129117], [-106590, -129117], [-106590, -126417], [-105950, -126417], [-105950, -126217]], [[-134830, -126417], [-134190, -126417], [-134190, -129117], [-134590, -129117], [-134590, -129317], [-133990, -129317], [-133990, -126217], [-134830, -126217]], [[-140590, -126217], [-140590, -129317], [-139990, -129317], [-139990, -129117], [-140390, -129117], [-140390, -126417], [-139750, -126417], [-139750, -126217]], [[-115190, -126817], [-114590, -126817], [-114590, -129117], [-114390, -129117], [-114390, -126617], [-115190, -126617]], [[-126190, -129117], [-126190, -126817], [-125590, -126817], [-125590, -126617], [-126390, -126617], [-126390, -129117]], [[-110990, -126217], [-110790, -126217], [-110790, -123917], [-110690, -123917], [-110690, -123717], [-110990, -123717]], [[-130090, -123917], [-129990, -123917], [-129990, -126217], [-129790, -126217], [-129790, -124717], [-129790, -123717], [-130090, -123717]], [[-115740, -124817], [-115090, -124817], [-114290, -124817], [-114040, -124817], [-114040, -124617], [-114290, -124617], [-115090, -124617], [-115540, -124617], [-115540, -123817], [-115740, -123817]], [[-125140, -124617], [-125690, -124617], [-126390, -124617], [-126640, -124617], [-126640, -124817], [-126390, -124817], [-125690, -124817], [-124940, -124817], [-124940, -123817], [-125140, -123817]], [[-106790, -123717], [-107190, -123717], [-107190, -123917], [-106590, -123917], [-106590, -122217], [-106790, -122217]], [[-134190, -123917], [-133590, -123917], [-133590, -123717], [-133990, -123717], [-133990, -122217], [-134190, -122217]], [[-133990, -118667], [-134390, -118667], [-134390, -119067], [-133990, -119067]], [[-129430, -118867], [-129190, -118867], [-129190, -120117], [-129190, -120667], [-128990, -120667], [-128990, -120217], [-126490, -120217], [-126490, -122217], [-128990, -122217], [-128990, -121767], [-129190, -121767], [-129190, -122417], [-126290, -122417], [-126290, -120017], [-128990, -120017], [-128990, -118667], [-129430, -118667]], [[-114190, -120117], [-112090, -120117], [-112090, -120617], [-111890, -120617], [-111890, -120017], [-111890, -118867], [-111690, -118867], [-111690, -118667], [-112090, -118667], [-112090, -119917], [-114390, -119917], [-114390, -122417], [-111890, -122417], [-111890, -121717], [-112090, -121717], [-112090, -122217], [-114190, -122217]], [[-106390, -118667], [-106790, -118667], [-106790, -119067], [-106390, -119067]], [[-120290, -124217], [-120090, -124217], [-120090, -124017]], [[-120090, -123817], [-120690, -123817], [-120690, -124217], [-120090, -124217]], [[-120690, -124017], [-120690, -124063]], [[82056, -80223], [82056, -80423], [82456, -80423], [82456, -82323], [82656, -82323], [82656, -80223]], [[81756, -88423], [81756, -88623], [82556, -88623], [83056, -88623], [83056, -88423], [82656, -88423], [82656, -86423], [82456, -86423], [82456, -88423]], [[75656, -88423], [75656, -88623], [76156, -88623], [76956, -88623], [76956, -88423], [76256, -88423], [76256, -86423], [76056, -86423], [76056, -88423]], [[76056, -82323], [76256, -82323], [76256, -80423], [76656, -80423], [76656, -80223], [76056, -80223]], [[88156, -88423], [88156, -88623], [88756, -88623], [88756, -86973], [88556, -86973], [88556, -88423]], [[91656, -88423], [91656, -88623], [92356, -88623], [92356, -86423], [92156, -86423], [92156, -88423]], [[70556, -88623], [70556, -88423], [70156, -88423], [70156, -86973], [69956, -86973], [69956, -88623]], [[67056, -88623], [67056, -88423], [66556, -88423], [66556, -86423], [66356, -86423], [66356, -88623]], [[92156, -81323], [92156, -84023], [91756, -84023], [91756, -84223], [92356, -84223], [92356, -81123], [91756, -81123], [91756, -81323]], [[79256, -84223], [79456, -84223], [80481, -84223], [80481, -83548], [80281, -83548], [80281, -84023], [79356, -84023], [78431, -84023], [78431, -83548], [78231, -83548], [78231, -84223]], [[85256, -80223], [85256, -80423], [85656, -80423], [85656, -81223], [85656, -84223], [86256, -84223], [86256, -84023], [85856, -84023], [85856, -81323], [86256, -81323], [86256, -81123], [85856, -81123], [85856, -80223]], [[72456, -81123], [72456, -81323], [72856, -81323], [72856, -84023], [72456, -84023], [72456, -84223], [73056, -84223], [73056, -81223], [73056, -80423], [73456, -80423], [73456, -80223], [72856, -80223], [72856, -81123]], [[78431, -81973], [80281, -81973], [80281, -82448], [80481, -82448], [80481, -81773], [78231, -81773], [78231, -82448], [78431, -82448]], [[66956, -84223], [66956, -84023], [66556, -84023], [66556, -81323], [66956, -81323], [66956, -81123], [66356, -81123], [66356, -84223]], [[50856, -88423], [50856, -88623], [50056, -88623], [49556, -88623], [49556, -88423], [49956, -88423], [49956, -86423], [50156, -86423], [50156, -88423]], [[56956, -88423], [56956, -88623], [56456, -88623], [55656, -88623], [55656, -88423], [56356, -88423], [56356, -86423], [56556, -86423], [56556, -88423]], [[50556, -80223], [50556, -80423], [50156, -80423], [50156, -82323], [49956, -82323], [49956, -80223]], [[56556, -82323], [56356, -82323], [56356, -80423], [55956, -80423], [55956, -80223], [56556, -80223]], [[40956, -88423], [40956, -88623], [40256, -88623], [40256, -86423], [40456, -86423], [40456, -88423]], [[44456, -88423], [44456, -88623], [43856, -88623], [43856, -86973], [44056, -86973], [44056, -88423]], [[62056, -88623], [62056, -88423], [62456, -88423], [62456, -86973], [62656, -86973], [62656, -88623]], [[65556, -88623], [65556, -88423], [66056, -88423], [66056, -86423], [66256, -86423], [66256, -88623]], [[40456, -81323], [40456, -84023], [40856, -84023], [40856, -84223], [40256, -84223], [40256, -81123], [40856, -81123], [40856, -81323]], [[47356, -80223], [47356, -80423], [46956, -80423], [46956, -81223], [46956, -84223], [46356, -84223], [46356, -84023], [46756, -84023], [46756, -81323], [46356, -81323], [46356, -81123], [46756, -81123], [46756, -80223]], [[53356, -84223], [53156, -84223], [52131, -84223], [52131, -83548], [52331, -83548], [52331, -84023], [53256, -84023], [54181, -84023], [54181, -83548], [54381, -83548], [54381, -84223]], [[60156, -81123], [60156, -81323], [59756, -81323], [59756, -84023], [60156, -84023], [60156, -84223], [59556, -84223], [59556, -81223], [59556, -80423], [59156, -80423], [59156, -80223], [59756, -80223], [59756, -81123]], [[65656, -84223], [65656, -84023], [66056, -84023], [66056, -81323], [65656, -81323], [65656, -81123], [66256, -81123], [66256, -84223]], [[54181, -81973], [52331, -81973], [52331, -82448], [52131, -82448], [52131, -81773], [54381, -81773], [54381, -82448], [54181, -82448]], [[52006, -76523], [52006, -76923], [51606, -76923], [51606, -76523]], [[54906, -76523], [54906, -76923], [54506, -76923], [54506, -76523]], [[52006, -76523], [52006, -76923], [51606, -76923], [51606, -76523]], [[54906, -76523], [54906, -76923], [54506, -76923], [54506, -76523]], [[80606, -76523], [80606, -76923], [81006, -76923], [81006, -76523]], [[77706, -76523], [77706, -76923], [78106, -76923], [78106, -76523]]], \"coreBarrel\": [[[76056, -80223], [77906, -80223], [77906, -76923], [77706, -76923], [77706, -76523], [81006, -76523], [81006, -76923], [80806, -76923], [80806, -80223], [82656, -80223], [82656, -84224], [76056, -84224]], [[56556, -80223], [54706, -80223], [54706, -76923], [54906, -76923], [54906, -76523], [51606, -76523], [51606, -76923], [51806, -76923], [51806, -80223], [49956, -80223], [49956, -84224], [56556, -84224]], [[30345, -124844], [28495, -124844], [28495, -121544], [28695, -121544], [28695, -121144], [25394, -121144], [25394, -121544], [25595, -121544], [25595, -124844], [23745, -124844], [23745, -128845], [30345, -128845]], [[-46349, -32334], [-46349, -35435], [-38350, -35435], [-38349, -29334], [-40549, -29334], [-40549, -28484], [-45149, -28484], [-45149, -29734], [-45849, -29734], [-45849, -32034], [-46349, -32034], [-46350, -32285]], [[-8950, 17923], [-8950, 14821], [-16949, 14821], [-16950, 20923], [-14750, 20923], [-14750, 21773], [-10150, 21773], [-10150, 20523], [-9450, 20523], [-9450, 18223], [-8950, 18223], [-8949, 17971]], [[12000, 17923], [12000, 14821], [20000, 14821], [20000, 20923], [17800, 20923], [17800, 21773], [13200, 21773], [13200, 20523], [12500, 20523], [12500, 18223], [12000, 18223], [12000, 17971]], [[47264, 68753], [47264, 71453], [45964, 71453], [45964, 73353], [45764, 73353], [45764, 76052], [40664, 76052], [40665, 68753]], [[-46307, 69670], [-46307, 66569], [-38307, 66569], [-38307, 72670], [-40507, 72670], [-40507, 73520], [-45107, 73520], [-45107, 72270], [-45807, 72270], [-45807, 69970], [-46307, 69970], [-46307, 69719]], [[47184, -18461], [47184, -15761], [45884, -15761], [45884, -13861], [45684, -13861], [45684, -11162], [40584, -11162], [40585, -18461]], [[-73157, 66721], [-73157, 69421], [-71857, 69421], [-71857, 71321], [-71657, 71321], [-71657, 74020], [-66557, 74020], [-66557, 66721]], [[66795, 68753], [66795, 71453], [68095, 71453], [68095, 73353], [68295, 73353], [68295, 76052], [73395, 76052], [73395, 68753]], [[66715, -18461], [66715, -15761], [68015, -15761], [68015, -13861], [68215, -13861], [68215, -11162], [73315, -11162], [73314, -18461]], [[-73200, -35283], [-73200, -32583], [-71900, -32583], [-71900, -30683], [-71700, -30683], [-71700, -27984], [-66599, -27984], [-66600, -35283]], [[111291, 45555], [108591, 45555], [108591, 46905], [103391, 46905], [103391, 41655], [107791, 41655], [107791, 43155], [111291, 43155]], [[130990, 46505], [131190, 46505], [131190, 46905], [125490, 46905], [125490, 45655], [123190, 45655], [123190, 41755], [121840, 41755], [121840, 40755], [122390, 40755], [122390, 40741], [126791, 40741], [126791, 41655], [130990, 41655]], [[111191, 117244], [108491, 117244], [108491, 118594], [103291, 118594], [103291, 113344], [107691, 113344], [107691, 114844], [111191, 114844]], [[130890, 118194], [131090, 118194], [131090, 118594], [125390, 118594], [125390, 117344], [123090, 117344], [123090, 113444], [121740, 113444], [121740, 112444], [122290, 112444], [122290, 112430], [126691, 112430], [126691, 113344], [130890, 113344]], [[2243, 105935], [-456, 105935], [-456, 107285], [-5656, 107285], [-5656, 102035], [-1256, 102035], [-1256, 103535], [2243, 103535]], [[21942, 106886], [22142, 106886], [22142, 107285], [16442, 107285], [16442, 106035], [14142, 106035], [14142, 102135], [12792, 102135], [12792, 101135], [13343, 101135], [13343, 101121], [17744, 101121], [17744, 102035], [21942, 102035]], [[-114094, 117446], [-116794, 117446], [-116794, 118796], [-121994, 118796], [-121994, 113546], [-117594, 113546], [-117594, 115046], [-114094, 115046]], [[-94395, 118396], [-94195, 118396], [-94195, 118796], [-99895, 118796], [-99895, 117546], [-102195, 117546], [-102195, 113646], [-103545, 113646], [-103545, 112646], [-102995, 112646], [-102995, 112632], [-98594, 112632], [-98594, 113546], [-94395, 113546]], [[-118375, 39660], [-121075, 39660], [-121075, 41010], [-126275, 41010], [-126275, 35760], [-121875, 35760], [-121875, 37260], [-118375, 37260]], [[-98676, 40611], [-98476, 40611], [-98476, 41010], [-104176, 41010], [-104176, 39760], [-106476, 39760], [-106476, 35860], [-107826, 35860], [-107826, 34860], [-107276, 34860], [-107276, 34846], [-102875, 34846], [-102875, 35760], [-98676, 35760]], [[-121958, -36998], [-124658, -36998], [-124658, -35648], [-129858, -35648], [-129858, -40898], [-125458, -40898], [-125458, -39398], [-121958, -39398]], [[-102258, -36048], [-102058, -36048], [-102058, -35648], [-107758, -35648], [-107758, -36898], [-110058, -36898], [-110058, -40798], [-111408, -40798], [-111408, -41798], [-110858, -41798], [-110858, -41812], [-106457, -41812], [-106457, -40898], [-102258, -40898]], [[4597, -67520], [4597, -64820], [5897, -64820], [5897, -62920], [6097, -62920], [6097, -60221], [11198, -60221], [11197, -67520]], [[-23692, -128544], [-23692, -125844], [-22392, -125844], [-22392, -123944], [-22192, -123944], [-22192, -121244], [-17091, -121244], [-17092, -128544]], [[-72691, -119734], [-75391, -119734], [-75391, -118384], [-80591, -118384], [-80591, -123634], [-76191, -123634], [-76191, -122134], [-72691, -122134]], [[-52992, -118784], [-52792, -118784], [-52792, -118384], [-58492, -118384], [-58492, -119634], [-60792, -119634], [-60792, -123534], [-62142, -123535], [-62142, -124534], [-61591, -124534], [-61591, -124549], [-57190, -124549], [-57190, -123634], [-52992, -123635]], [[-126290, -120017], [-128990, -120017], [-128990, -118667], [-134190, -118667], [-134190, -123917], [-129790, -123917], [-129790, -122417], [-126290, -122417]], [[-106591, -119067], [-106391, -119067], [-106391, -118667], [-112091, -118667], [-112091, -119917], [-114391, -119917], [-114391, -123817], [-115741, -123817], [-115741, -124817], [-115190, -124817], [-115190, -124831], [-110789, -124831], [-110789, -123917], [-106591, -123917]]], \"outer\": [[40145, -142925], [-141871, -143885], [-140019, -113609], [-136925, -52356], [-134334, -1064], [-131560, 64767], [-127594, 127053], [142537, 126837], [142537, 103], [92456, 103], [92456, -90223], [40145, -90223], [40145, -142925]], \"params\": {\"column_length\": 0.6, \"column_type\": 1, \"column_width\": 0.6, \"lane_width\": 5.5, \"out_line_type\": \"core\", \"park_length\": 5.1, \"park_width\": 2.4, \"parking_count\": 1493, \"wall_park_length\": 5.3}, \"projectId\": 131, \"recalculate_equipment\": [], \"recalculate_gates\": [], \"taskId\": \"1\"}"
    # data = json.loads(value)
    # for x in range(100):
    #     data["taskId"] = str(int(data["taskId"]) + int(x))
    #     value = json.dumps(data)
    #     # log.info("入队列key:" + queue_key + ",入队列value:" + value + str(x))
    #     lPush(queue_key, value)
    # msg = "TypeError: descriptor 'encode' for 'str' objects doesn't apply to a 'bytes' object"
    # taskId = "1131473191623214108672"
    # # task_data = re_pool.hget(aisr_task_data_key, taskId)
    # # task_data_str = bytes.decode(task_data, "utf-8")
    # errorTaskStatus(taskId, msg)
    # for x in range(1, 10):
    #     log.info("出队列内容:" + rPop(queue_key))
    # restartTodoRunTask("1301474280540101283840")
    # d = getHash("aisr:park_task_data","4271501943917891948544")
